Documentation
¶
Overview ¶
Package config contains service configuration endpoints and data definition for crosskylabadmin.
Index ¶
- Variables
- func Import(c context.Context) error
- func Middleware(c *router.Context, next router.Handler)
- func Use(c context.Context, cfg *Config) context.Context
- type Config
- func (*Config) Descriptor() ([]byte, []int)deprecated
- func (x *Config) GetAccessGroup() string
- func (x *Config) GetCron() *Cron
- func (x *Config) GetEndpoint() *Endpoint
- func (x *Config) GetInventory() *Inventory
- func (x *Config) GetInventoryProvider() *InventoryProvider
- func (x *Config) GetRpcControl() *RPCControl
- func (x *Config) GetStableVersionConfig() *StableVersionConfig
- func (x *Config) GetSwarming() *Swarming
- func (x *Config) GetTasker() *Tasker
- func (*Config) ProtoMessage()
- func (x *Config) ProtoReflect() protoreflect.Message
- func (x *Config) Reset()
- func (x *Config) String() string
- type Cron
- func (*Cron) Descriptor() ([]byte, []int)deprecated
- func (x *Cron) GetEnsureTasksCount() int32
- func (x *Cron) GetFleetAdminTaskPriority() int64
- func (x *Cron) GetPoolBalancer() *PoolBalancer
- func (x *Cron) GetRepairAttemptDelayDuration() *durationpb.Duration
- func (x *Cron) GetRepairIdleDuration() *durationpb.Duration
- func (*Cron) ProtoMessage()
- func (x *Cron) ProtoReflect() protoreflect.Message
- func (x *Cron) Reset()
- func (x *Cron) String() string
- type DeployDut
- func (*DeployDut) Descriptor() ([]byte, []int)deprecated
- func (x *DeployDut) GetTaskExecutionTimeout() *durationpb.Duration
- func (x *DeployDut) GetTaskExpirationTimeout() *durationpb.Duration
- func (x *DeployDut) GetTaskPriority() int64
- func (*DeployDut) ProtoMessage()
- func (x *DeployDut) ProtoReflect() protoreflect.Message
- func (x *DeployDut) Reset()
- func (x *DeployDut) String() string
- type Endpoint
- type Inventory
- func (*Inventory) Descriptor() ([]byte, []int)deprecated
- func (x *Inventory) GetBranch() string
- func (x *Inventory) GetDataPath() stringdeprecated
- func (x *Inventory) GetDeviceConfigBranch() string
- func (x *Inventory) GetDeviceConfigPath() string
- func (x *Inventory) GetDeviceConfigProject() string
- func (x *Inventory) GetDutInfoCacheValidity() *durationpb.Duration
- func (x *Inventory) GetEnvironment() string
- func (x *Inventory) GetGerritHost() string
- func (x *Inventory) GetGitilesHost() string
- func (x *Inventory) GetInfrastructureDataPath() string
- func (x *Inventory) GetLabDataPath() string
- func (x *Inventory) GetManufacturingConfigBranch() string
- func (x *Inventory) GetManufacturingConfigPath() string
- func (x *Inventory) GetManufacturingConfigProject() string
- func (x *Inventory) GetMultifile() bool
- func (x *Inventory) GetProject() string
- func (x *Inventory) GetQueenService() string
- func (x *Inventory) GetUpdateLimitPerMinute() int32
- func (*Inventory) ProtoMessage()
- func (x *Inventory) ProtoReflect() protoreflect.Message
- func (x *Inventory) Reset()
- func (x *Inventory) String() string
- type InventoryProvider
- func (*InventoryProvider) Descriptor() ([]byte, []int)deprecated
- func (x *InventoryProvider) GetHost() string
- func (x *InventoryProvider) GetInventoryV2Only() bool
- func (x *InventoryProvider) GetReadTrafficRatio() uint32
- func (x *InventoryProvider) GetTestingDeviceNames() []string
- func (x *InventoryProvider) GetTestingDeviceUuids() []string
- func (x *InventoryProvider) GetTrafficRatio() uint32deprecated
- func (x *InventoryProvider) GetWriteTrafficRatio() uint32
- func (*InventoryProvider) ProtoMessage()
- func (x *InventoryProvider) ProtoReflect() protoreflect.Message
- func (x *InventoryProvider) Reset()
- func (x *InventoryProvider) String() string
- type PoolBalancer
- func (*PoolBalancer) Descriptor() ([]byte, []int)deprecated
- func (x *PoolBalancer) GetMaxUnhealthyDuts() int32
- func (x *PoolBalancer) GetSparePool() string
- func (x *PoolBalancer) GetTargetPools() []string
- func (*PoolBalancer) ProtoMessage()
- func (x *PoolBalancer) ProtoReflect() protoreflect.Message
- func (x *PoolBalancer) Reset()
- func (x *PoolBalancer) String() string
- type RPCControl
- func (*RPCControl) Descriptor() ([]byte, []int)deprecated
- func (x *RPCControl) GetDisableDumpStableVersionToDatastore() bool
- func (x *RPCControl) GetDisableEnsureBackgroundTasks() bool
- func (x *RPCControl) GetDisableEnsureCriticalPoolsHealthy() bool
- func (x *RPCControl) GetDisablePushBotsForAdminTasks() bool
- func (x *RPCControl) GetDisablePushDutsForAdminAudit() bool
- func (x *RPCControl) GetDisablePushLabstationsForRepair() bool
- func (x *RPCControl) GetDisableRefreshBots() bool
- func (x *RPCControl) GetDisableRefreshInventory() bool
- func (x *RPCControl) GetDisableTriggerRepairOnIdle() bool
- func (x *RPCControl) GetDisableTriggerRepairOnRepairFailed() bool
- func (*RPCControl) ProtoMessage()
- func (x *RPCControl) ProtoReflect() protoreflect.Message
- func (x *RPCControl) Reset()
- func (x *RPCControl) String() string
- type StableVersionConfig
- func (*StableVersionConfig) Descriptor() ([]byte, []int)deprecated
- func (x *StableVersionConfig) GetBranch() string
- func (x *StableVersionConfig) GetGerritHost() string
- func (x *StableVersionConfig) GetGitilesHost() string
- func (x *StableVersionConfig) GetProject() string
- func (x *StableVersionConfig) GetStableVersionDataPath() string
- func (*StableVersionConfig) ProtoMessage()
- func (x *StableVersionConfig) ProtoReflect() protoreflect.Message
- func (x *StableVersionConfig) Reset()
- func (x *StableVersionConfig) String() string
- type Swarming
- func (*Swarming) Descriptor() ([]byte, []int)deprecated
- func (x *Swarming) GetBotPool() string
- func (x *Swarming) GetFleetAdminTaskTag() string
- func (x *Swarming) GetHost() string
- func (x *Swarming) GetLuciProjectTag() string
- func (*Swarming) ProtoMessage()
- func (x *Swarming) ProtoReflect() protoreflect.Message
- func (x *Swarming) Reset()
- func (x *Swarming) String() string
- type Tasker
- func (*Tasker) Descriptor() ([]byte, []int)deprecated
- func (x *Tasker) GetAdminTaskRealm() string
- func (x *Tasker) GetAdminTaskServiceAccount() string
- func (x *Tasker) GetBackgroundTaskExecutionTimeoutSecs() int64
- func (x *Tasker) GetBackgroundTaskExpirationSecs() int64
- func (x *Tasker) GetLogdogHost() string
- func (*Tasker) ProtoMessage()
- func (x *Tasker) ProtoReflect() protoreflect.Message
- func (x *Tasker) Reset()
- func (x *Tasker) String() string
Constants ¶
This section is empty.
Variables ¶
var File_infra_appengine_crosskylabadmin_app_config_config_proto protoreflect.FileDescriptor
Functions ¶
func Import ¶
Import fetches the most recent config and stores it in the datastore.
Must be called periodically to make sure Get and Middleware use the freshest config.
func Middleware ¶
Middleware loads the service config and installs it into the context.
Types ¶
type Config ¶
type Config struct {
// AccessGroup is the luci-auth group controlling access to admin app APIs.
AccessGroup string `protobuf:"bytes,1,opt,name=access_group,json=accessGroup,proto3" json:"access_group,omitempty"`
// Swarming contains information about the Swarming instance that hosts the
// bots managed by this app.
Swarming *Swarming `protobuf:"bytes,2,opt,name=swarming,proto3" json:"swarming,omitempty"`
// Tasker contains configuration data specific to the Tasker API endpoints.
Tasker *Tasker `protobuf:"bytes,3,opt,name=tasker,proto3" json:"tasker,omitempty"`
// Cron contains the configuration data specific to cron jobs on this app.
Cron *Cron `protobuf:"bytes,4,opt,name=cron,proto3" json:"cron,omitempty"`
// Inventory contains configuration information about skylab inventory
// repo.
Inventory *Inventory `protobuf:"bytes,5,opt,name=inventory,proto3" json:"inventory,omitempty"`
// endpoint contains configuration of specific API endpoints.
Endpoint *Endpoint `protobuf:"bytes,6,opt,name=endpoint,proto3" json:"endpoint,omitempty"`
// RPCcontrol controls rpc traffic.
RpcControl *RPCControl `protobuf:"bytes,7,opt,name=rpc_control,json=rpcControl,proto3" json:"rpc_control,omitempty"`
// StableVersionConfig determines the location of stable version related information
StableVersionConfig *StableVersionConfig `protobuf:"bytes,8,opt,name=stable_version_config,json=stableVersionConfig,proto3" json:"stable_version_config,omitempty"`
// InventoryProvider contains configuration of inventory provider, e.g.
// inventory v2 service.
InventoryProvider *InventoryProvider `protobuf:"bytes,9,opt,name=inventory_provider,json=inventoryProvider,proto3" json:"inventory_provider,omitempty"`
// contains filtered or unexported fields
}
Config is the configuration data served by luci-config for this app.
func (*Config) Descriptor
deprecated
func (*Config) GetAccessGroup ¶
func (*Config) GetEndpoint ¶
func (*Config) GetInventory ¶
func (*Config) GetInventoryProvider ¶
func (x *Config) GetInventoryProvider() *InventoryProvider
func (*Config) GetRpcControl ¶
func (x *Config) GetRpcControl() *RPCControl
func (*Config) GetStableVersionConfig ¶
func (x *Config) GetStableVersionConfig() *StableVersionConfig
func (*Config) GetSwarming ¶
func (*Config) ProtoMessage ¶
func (*Config) ProtoMessage()
func (*Config) ProtoReflect ¶
func (x *Config) ProtoReflect() protoreflect.Message
type Cron ¶
type Cron struct {
// FleetAdminTaskPriority is the swarming task priority of created tasks.
//
// This must be numerically smaller (i.e. more important) than Skylab's test
// task priority range [49-255] and numerically larger than the minimum
// allowed Swarming priority (20) for non administrator users.
FleetAdminTaskPriority int64 `` /* 132-byte string literal not displayed */
// EnsureTasksCount is the number of background tasks maintained against
// each bot.
EnsureTasksCount int32 `protobuf:"varint,2,opt,name=ensure_tasks_count,json=ensureTasksCount,proto3" json:"ensure_tasks_count,omitempty"`
// RepairIdleDuration is the duration for which a bot in the fleet must have
// been idle for a repair task to be created against it.
RepairIdleDuration *durationpb.Duration `protobuf:"bytes,3,opt,name=repair_idle_duration,json=repairIdleDuration,proto3" json:"repair_idle_duration,omitempty"`
// RepairAttemptDelayDuration is the time between successive attempts at
// repairing repair failed bots in the fleet.
RepairAttemptDelayDuration *durationpb.Duration `` /* 143-byte string literal not displayed */
// Configuration of automatic pool balancing to keep critical pools healthy.
PoolBalancer *PoolBalancer `protobuf:"bytes,5,opt,name=pool_balancer,json=poolBalancer,proto3" json:"pool_balancer,omitempty"`
// contains filtered or unexported fields
}
Cron contains the configuration data specific to cron jobs on this app.
func (*Cron) Descriptor
deprecated
func (*Cron) GetEnsureTasksCount ¶
func (*Cron) GetFleetAdminTaskPriority ¶
func (*Cron) GetPoolBalancer ¶
func (x *Cron) GetPoolBalancer() *PoolBalancer
func (*Cron) GetRepairAttemptDelayDuration ¶
func (x *Cron) GetRepairAttemptDelayDuration() *durationpb.Duration
func (*Cron) GetRepairIdleDuration ¶
func (x *Cron) GetRepairIdleDuration() *durationpb.Duration
func (*Cron) ProtoMessage ¶
func (*Cron) ProtoMessage()
func (*Cron) ProtoReflect ¶
func (x *Cron) ProtoReflect() protoreflect.Message
type DeployDut ¶
type DeployDut struct {
// Amount of time the deploy Skylab task can be PENDING.
//
// This should be long enough for the newly updated inventory information to
// propagate to the Swarming bots.
TaskExpirationTimeout *durationpb.Duration `` /* 126-byte string literal not displayed */
// Amount of time the deploy Skylab task is allowed to run.
//
// This should be enough for possibly installing firmware and test image on
// the DUT.
TaskExecutionTimeout *durationpb.Duration `protobuf:"bytes,2,opt,name=task_execution_timeout,json=taskExecutionTimeout,proto3" json:"task_execution_timeout,omitempty"`
// Priority of the deploy Skylab task.
//
// This should be the same as, or higher priority (i.e., numerically lower)
// than other admin tasks.
TaskPriority int64 `protobuf:"varint,3,opt,name=task_priority,json=taskPriority,proto3" json:"task_priority,omitempty"`
// contains filtered or unexported fields
}
func (*DeployDut) Descriptor
deprecated
func (*DeployDut) GetTaskExecutionTimeout ¶
func (x *DeployDut) GetTaskExecutionTimeout() *durationpb.Duration
func (*DeployDut) GetTaskExpirationTimeout ¶
func (x *DeployDut) GetTaskExpirationTimeout() *durationpb.Duration
func (*DeployDut) GetTaskPriority ¶
func (*DeployDut) ProtoMessage ¶
func (*DeployDut) ProtoMessage()
func (*DeployDut) ProtoReflect ¶
func (x *DeployDut) ProtoReflect() protoreflect.Message
type Endpoint ¶
type Endpoint struct {
DeployDut *DeployDut `protobuf:"bytes,1,opt,name=deploy_dut,json=deployDut,proto3" json:"deploy_dut,omitempty"`
// contains filtered or unexported fields
}
func (*Endpoint) Descriptor
deprecated
func (*Endpoint) GetDeployDut ¶
func (*Endpoint) ProtoMessage ¶
func (*Endpoint) ProtoMessage()
func (*Endpoint) ProtoReflect ¶
func (x *Endpoint) ProtoReflect() protoreflect.Message
type Inventory ¶
type Inventory struct {
// Gitiles server hosting inventory project.
// e.g. chromium.googlesource.com
GitilesHost string `protobuf:"bytes,1,opt,name=gitiles_host,json=gitilesHost,proto3" json:"gitiles_host,omitempty"`
// Gerrit code review server hosting inventory project.
// e.g. chromium-review.googlesource.com
GerritHost string `protobuf:"bytes,2,opt,name=gerrit_host,json=gerritHost,proto3" json:"gerrit_host,omitempty"`
// Git project containing the inventory data.
Project string `protobuf:"bytes,3,opt,name=project,proto3" json:"project,omitempty"`
// Git branch from the inventory project to be used.
Branch string `protobuf:"bytes,4,opt,name=branch,proto3" json:"branch,omitempty"`
// Deprecated: Do not use.
DataPath string `protobuf:"bytes,5,opt,name=data_path,json=dataPath,proto3" json:"data_path,omitempty"`
// Inventory environment managed by this instance of the app.
// e.g. ENVIRONMENT_STAGING
Environment string `protobuf:"bytes,6,opt,name=environment,proto3" json:"environment,omitempty"`
// Path to the infrastructure inventory data file within the git project.
// e.g. data/skylab/server_db.textpb
InfrastructureDataPath string `` /* 129-byte string literal not displayed */
// Path to the lab inventory data file within the git project.
// e.g. data/skylab/lab.textpb
LabDataPath string `protobuf:"bytes,8,opt,name=lab_data_path,json=labDataPath,proto3" json:"lab_data_path,omitempty"`
// dut_info_cache_validty is the amount of time cached inventory information
// about a DUT is valid after being refreshed.
//
// This duration should be long enough to
// (1) smooth over any refresh failures due to backing gitiles flake or quota
// issues.
// (2) Allow a human to interfere and fix corrupt inventory data about (some)
// DUTs.
//
// A DUT will continue to live in the cache (and hence be served via various
// RPCs) for dut_info_cache_validity after it has been deleted from the
// inventory.
DutInfoCacheValidity *durationpb.Duration `protobuf:"bytes,9,opt,name=dut_info_cache_validity,json=dutInfoCacheValidity,proto3" json:"dut_info_cache_validity,omitempty"`
// update_limit_per_minute is used to rate limit some inventory updates.
UpdateLimitPerMinute int32 `` /* 127-byte string literal not displayed */
// Queen service to push inventory to.
QueenService string `protobuf:"bytes,11,opt,name=queen_service,json=queenService,proto3" json:"queen_service,omitempty"`
// Git project containing the device config.
DeviceConfigProject string `protobuf:"bytes,12,opt,name=device_config_project,json=deviceConfigProject,proto3" json:"device_config_project,omitempty"`
// Git branch from the device config project to be used.
DeviceConfigBranch string `protobuf:"bytes,13,opt,name=device_config_branch,json=deviceConfigBranch,proto3" json:"device_config_branch,omitempty"`
// The device config file path.
// e.g. deviceconfig/generated/device_configs.cfg
DeviceConfigPath string `protobuf:"bytes,14,opt,name=device_config_path,json=deviceConfigPath,proto3" json:"device_config_path,omitempty"`
// If using multi files for inventory. See crbug.com/1008442 for details.
Multifile bool `protobuf:"varint,15,opt,name=multifile,proto3" json:"multifile,omitempty"`
// Git project containing the manufacturing config.
ManufacturingConfigProject string `` /* 142-byte string literal not displayed */
// Git branch from the manufacturing config project to be used.
ManufacturingConfigBranch string `` /* 139-byte string literal not displayed */
// The device config file path.
// e.g. manufacturingconfig/generated/manufacturing_configs.cfg
ManufacturingConfigPath string `` /* 133-byte string literal not displayed */
// contains filtered or unexported fields
}
Skylab inventory is stored in a git project. A Gitiles server as well as Gerrit review server are used by this app to view and update the inventory data.
func (*Inventory) Descriptor
deprecated
func (*Inventory) GetDataPath
deprecated
func (*Inventory) GetDeviceConfigBranch ¶
func (*Inventory) GetDeviceConfigPath ¶
func (*Inventory) GetDeviceConfigProject ¶
func (*Inventory) GetDutInfoCacheValidity ¶
func (x *Inventory) GetDutInfoCacheValidity() *durationpb.Duration
func (*Inventory) GetEnvironment ¶
func (*Inventory) GetGerritHost ¶
func (*Inventory) GetGitilesHost ¶
func (*Inventory) GetInfrastructureDataPath ¶
func (*Inventory) GetLabDataPath ¶
func (*Inventory) GetManufacturingConfigBranch ¶
func (*Inventory) GetManufacturingConfigPath ¶
func (*Inventory) GetManufacturingConfigProject ¶
func (*Inventory) GetMultifile ¶
func (*Inventory) GetProject ¶
func (*Inventory) GetQueenService ¶
func (*Inventory) GetUpdateLimitPerMinute ¶
func (*Inventory) ProtoMessage ¶
func (*Inventory) ProtoMessage()
func (*Inventory) ProtoReflect ¶
func (x *Inventory) ProtoReflect() protoreflect.Message
type InventoryProvider ¶
type InventoryProvider struct {
// The inventory service hostname, e.g. "cros-lab-inventory.appspot.com".
Host string `protobuf:"bytes,1,opt,name=host,proto3" json:"host,omitempty"`
// TODO (guocb) Remove `traffic_ratio` `read_traffic_ratio` and
// `write_traffic_ratio` after migration.
//
// Deprecated: Do not use.
TrafficRatio uint32 `protobuf:"varint,2,opt,name=traffic_ratio,json=trafficRatio,proto3" json:"traffic_ratio,omitempty"`
// The ratio (a number in [0, 100]) of reading traffic FAN OUT to inventory
// service. Just for migrating purpose.
ReadTrafficRatio uint32 `protobuf:"varint,3,opt,name=read_traffic_ratio,json=readTrafficRatio,proto3" json:"read_traffic_ratio,omitempty"`
// The ratio (a number in [0, 100]) of reading traffic DUPLICATED to
// inventory service. Just for migrating purpose.
WriteTrafficRatio uint32 `protobuf:"varint,4,opt,name=write_traffic_ratio,json=writeTrafficRatio,proto3" json:"write_traffic_ratio,omitempty"`
// The device uuids for migration testing.
TestingDeviceUuids []string `protobuf:"bytes,5,rep,name=testing_device_uuids,json=testingDeviceUuids,proto3" json:"testing_device_uuids,omitempty"`
// The device names for migration testing.
TestingDeviceNames []string `protobuf:"bytes,6,rep,name=testing_device_names,json=testingDeviceNames,proto3" json:"testing_device_names,omitempty"`
// The flag to control if we write to inventory v1.
InventoryV2Only bool `protobuf:"varint,7,opt,name=inventory_v2_only,json=inventoryV2Only,proto3" json:"inventory_v2_only,omitempty"`
// contains filtered or unexported fields
}
func (*InventoryProvider) Descriptor
deprecated
func (*InventoryProvider) Descriptor() ([]byte, []int)
Deprecated: Use InventoryProvider.ProtoReflect.Descriptor instead.
func (*InventoryProvider) GetHost ¶
func (x *InventoryProvider) GetHost() string
func (*InventoryProvider) GetInventoryV2Only ¶
func (x *InventoryProvider) GetInventoryV2Only() bool
func (*InventoryProvider) GetReadTrafficRatio ¶
func (x *InventoryProvider) GetReadTrafficRatio() uint32
func (*InventoryProvider) GetTestingDeviceNames ¶
func (x *InventoryProvider) GetTestingDeviceNames() []string
func (*InventoryProvider) GetTestingDeviceUuids ¶
func (x *InventoryProvider) GetTestingDeviceUuids() []string
func (*InventoryProvider) GetTrafficRatio
deprecated
func (x *InventoryProvider) GetTrafficRatio() uint32
Deprecated: Do not use.
func (*InventoryProvider) GetWriteTrafficRatio ¶
func (x *InventoryProvider) GetWriteTrafficRatio() uint32
func (*InventoryProvider) ProtoMessage ¶
func (*InventoryProvider) ProtoMessage()
func (*InventoryProvider) ProtoReflect ¶
func (x *InventoryProvider) ProtoReflect() protoreflect.Message
func (*InventoryProvider) Reset ¶
func (x *InventoryProvider) Reset()
func (*InventoryProvider) String ¶
func (x *InventoryProvider) String() string
type PoolBalancer ¶
type PoolBalancer struct {
// Names of the pools to keep healthy automatically via pool balancing.
TargetPools []string `protobuf:"bytes,1,rep,name=target_pools,json=targetPools,proto3" json:"target_pools,omitempty"`
// Name of the pool to use as the spare pool for pool balancing.
SparePool string `protobuf:"bytes,2,opt,name=spare_pool,json=sparePool,proto3" json:"spare_pool,omitempty"`
// Maximum number of unhealthy DUTs per model that can be balanced away from
// a single target pool.
MaxUnhealthyDuts int32 `protobuf:"varint,3,opt,name=max_unhealthy_duts,json=maxUnhealthyDuts,proto3" json:"max_unhealthy_duts,omitempty"`
// contains filtered or unexported fields
}
func (*PoolBalancer) Descriptor
deprecated
func (*PoolBalancer) Descriptor() ([]byte, []int)
Deprecated: Use PoolBalancer.ProtoReflect.Descriptor instead.
func (*PoolBalancer) GetMaxUnhealthyDuts ¶
func (x *PoolBalancer) GetMaxUnhealthyDuts() int32
func (*PoolBalancer) GetSparePool ¶
func (x *PoolBalancer) GetSparePool() string
func (*PoolBalancer) GetTargetPools ¶
func (x *PoolBalancer) GetTargetPools() []string
func (*PoolBalancer) ProtoMessage ¶
func (*PoolBalancer) ProtoMessage()
func (*PoolBalancer) ProtoReflect ¶
func (x *PoolBalancer) ProtoReflect() protoreflect.Message
func (*PoolBalancer) Reset ¶
func (x *PoolBalancer) Reset()
func (*PoolBalancer) String ¶
func (x *PoolBalancer) String() string
type RPCControl ¶
type RPCControl struct {
// Configuration of if disabling some rpc calls. It's used in experimental stage.
// Once an RPC call is verified to be working/useless, it will be added/deleted.
DisableEnsureBackgroundTasks bool `` /* 150-byte string literal not displayed */
DisableEnsureCriticalPoolsHealthy bool `` /* 167-byte string literal not displayed */
DisablePushBotsForAdminTasks bool `` /* 154-byte string literal not displayed */
DisableRefreshBots bool `protobuf:"varint,4,opt,name=disable_refresh_bots,json=disableRefreshBots,proto3" json:"disable_refresh_bots,omitempty"`
DisableRefreshInventory bool `` /* 133-byte string literal not displayed */
DisableTriggerRepairOnIdle bool `` /* 146-byte string literal not displayed */
DisableTriggerRepairOnRepairFailed bool `` /* 172-byte string literal not displayed */
DisablePushLabstationsForRepair bool `` /* 161-byte string literal not displayed */
DisableDumpStableVersionToDatastore bool `` /* 175-byte string literal not displayed */
DisablePushDutsForAdminAudit bool `` /* 155-byte string literal not displayed */
// contains filtered or unexported fields
}
next tag: 11
func (*RPCControl) Descriptor
deprecated
func (*RPCControl) Descriptor() ([]byte, []int)
Deprecated: Use RPCControl.ProtoReflect.Descriptor instead.
func (*RPCControl) GetDisableDumpStableVersionToDatastore ¶
func (x *RPCControl) GetDisableDumpStableVersionToDatastore() bool
func (*RPCControl) GetDisableEnsureBackgroundTasks ¶
func (x *RPCControl) GetDisableEnsureBackgroundTasks() bool
func (*RPCControl) GetDisableEnsureCriticalPoolsHealthy ¶
func (x *RPCControl) GetDisableEnsureCriticalPoolsHealthy() bool
func (*RPCControl) GetDisablePushBotsForAdminTasks ¶
func (x *RPCControl) GetDisablePushBotsForAdminTasks() bool
func (*RPCControl) GetDisablePushDutsForAdminAudit ¶
func (x *RPCControl) GetDisablePushDutsForAdminAudit() bool
func (*RPCControl) GetDisablePushLabstationsForRepair ¶
func (x *RPCControl) GetDisablePushLabstationsForRepair() bool
func (*RPCControl) GetDisableRefreshBots ¶
func (x *RPCControl) GetDisableRefreshBots() bool
func (*RPCControl) GetDisableRefreshInventory ¶
func (x *RPCControl) GetDisableRefreshInventory() bool
func (*RPCControl) GetDisableTriggerRepairOnIdle ¶
func (x *RPCControl) GetDisableTriggerRepairOnIdle() bool
func (*RPCControl) GetDisableTriggerRepairOnRepairFailed ¶
func (x *RPCControl) GetDisableTriggerRepairOnRepairFailed() bool
func (*RPCControl) ProtoMessage ¶
func (*RPCControl) ProtoMessage()
func (*RPCControl) ProtoReflect ¶
func (x *RPCControl) ProtoReflect() protoreflect.Message
func (*RPCControl) Reset ¶
func (x *RPCControl) Reset()
func (*RPCControl) String ¶
func (x *RPCControl) String() string
type StableVersionConfig ¶
type StableVersionConfig struct {
// The Gerrit Server for the stable version data file's repo
// example: "chrome-internal-review.googlesource.com"
GerritHost string `protobuf:"bytes,1,opt,name=gerrit_host,json=gerritHost,proto3" json:"gerrit_host,omitempty"`
// The Gitiles Server for the stable version data file's repo
// example: "chrome-internal.googlesource.com"
GitilesHost string `protobuf:"bytes,2,opt,name=gitiles_host,json=gitilesHost,proto3" json:"gitiles_host,omitempty"`
// The project name for the stable version data file's repo
// example: "chromeos/infra/config"
Project string `protobuf:"bytes,3,opt,name=project,proto3" json:"project,omitempty"`
// The branch that the stable version data file is on
// example: "main"
Branch string `protobuf:"bytes,4,opt,name=branch,proto3" json:"branch,omitempty"`
// The path, relative to the repo root, of the stable version data file
// example: "lab_platform/stable_version_data/stable_versions.cfg"
StableVersionDataPath string `` /* 128-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*StableVersionConfig) Descriptor
deprecated
func (*StableVersionConfig) Descriptor() ([]byte, []int)
Deprecated: Use StableVersionConfig.ProtoReflect.Descriptor instead.
func (*StableVersionConfig) GetBranch ¶
func (x *StableVersionConfig) GetBranch() string
func (*StableVersionConfig) GetGerritHost ¶
func (x *StableVersionConfig) GetGerritHost() string
func (*StableVersionConfig) GetGitilesHost ¶
func (x *StableVersionConfig) GetGitilesHost() string
func (*StableVersionConfig) GetProject ¶
func (x *StableVersionConfig) GetProject() string
func (*StableVersionConfig) GetStableVersionDataPath ¶
func (x *StableVersionConfig) GetStableVersionDataPath() string
func (*StableVersionConfig) ProtoMessage ¶
func (*StableVersionConfig) ProtoMessage()
func (*StableVersionConfig) ProtoReflect ¶
func (x *StableVersionConfig) ProtoReflect() protoreflect.Message
func (*StableVersionConfig) Reset ¶
func (x *StableVersionConfig) Reset()
func (*StableVersionConfig) String ¶
func (x *StableVersionConfig) String() string
type Swarming ¶
type Swarming struct {
// Host is the swarming instance hosting skylab bots.
Host string `protobuf:"bytes,1,opt,name=host,proto3" json:"host,omitempty"`
// BotPool is the swarming pool containing skylab bots.
BotPool string `protobuf:"bytes,2,opt,name=bot_pool,json=botPool,proto3" json:"bot_pool,omitempty"`
// FleetAdminTaskTag identifies all tasks created by the fleet admin app.
FleetAdminTaskTag string `protobuf:"bytes,3,opt,name=fleet_admin_task_tag,json=fleetAdminTaskTag,proto3" json:"fleet_admin_task_tag,omitempty"`
// LuciProjectTag is the swarming tag that associates the task with a
// luci project, allowing milo to work with the swarming UI.
LuciProjectTag string `protobuf:"bytes,4,opt,name=luci_project_tag,json=luciProjectTag,proto3" json:"luci_project_tag,omitempty"`
// contains filtered or unexported fields
}
Swarming contains information about the Swarming instance that hosts the bots managed by this app.
func (*Swarming) Descriptor
deprecated
func (*Swarming) GetBotPool ¶
func (*Swarming) GetFleetAdminTaskTag ¶
func (*Swarming) GetLuciProjectTag ¶
func (*Swarming) ProtoMessage ¶
func (*Swarming) ProtoMessage()
func (*Swarming) ProtoReflect ¶
func (x *Swarming) ProtoReflect() protoreflect.Message
type Tasker ¶
type Tasker struct {
// BackgroundTaskExecutionTimeoutSecs is the execution timeout (in
// seconds) for background tasks created by tasker.
BackgroundTaskExecutionTimeoutSecs int64 `` /* 170-byte string literal not displayed */
// BackgroundTaskExpirationSecs is the expiration time (in seconds) for
// background tasks created by tasker.
BackgroundTaskExpirationSecs int64 `` /* 150-byte string literal not displayed */
// LogdogHost is the Logdog host to use for logging from the created tasks.
LogdogHost string `protobuf:"bytes,3,opt,name=logdog_host,json=logdogHost,proto3" json:"logdog_host,omitempty"`
// AdminTaskServiceAccount is the name of the service account to use for admin
// tasks.
AdminTaskServiceAccount string `` /* 134-byte string literal not displayed */
// AdminTaskRealm is a LUCI realm name with ACLs for admin tasks.
AdminTaskRealm string `protobuf:"bytes,5,opt,name=admin_task_realm,json=adminTaskRealm,proto3" json:"admin_task_realm,omitempty"`
// contains filtered or unexported fields
}
Tasker contains configuration data specific to the Tasker API endpoints.
func (*Tasker) Descriptor
deprecated
func (*Tasker) GetAdminTaskRealm ¶
func (*Tasker) GetAdminTaskServiceAccount ¶
func (*Tasker) GetBackgroundTaskExecutionTimeoutSecs ¶
func (*Tasker) GetBackgroundTaskExpirationSecs ¶
func (*Tasker) GetLogdogHost ¶
func (*Tasker) ProtoMessage ¶
func (*Tasker) ProtoMessage()
func (*Tasker) ProtoReflect ¶
func (x *Tasker) ProtoReflect() protoreflect.Message