Documentation
¶
Index ¶
- func FileDescriptorSet() *descriptor.FileDescriptorSet
- func RegisterRotationProxyServiceServer(s prpc.Registrar, srv RotationProxyServiceServer)
- type BatchGetRotationsRequest
- func (*BatchGetRotationsRequest) Descriptor() ([]byte, []int)
- func (m *BatchGetRotationsRequest) GetNames() []string
- func (*BatchGetRotationsRequest) ProtoMessage()
- func (m *BatchGetRotationsRequest) Reset()
- func (m *BatchGetRotationsRequest) String() string
- func (m *BatchGetRotationsRequest) XXX_DiscardUnknown()
- func (m *BatchGetRotationsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *BatchGetRotationsRequest) XXX_Merge(src proto.Message)
- func (m *BatchGetRotationsRequest) XXX_Size() int
- func (m *BatchGetRotationsRequest) XXX_Unmarshal(b []byte) error
- type BatchGetRotationsResponse
- func (*BatchGetRotationsResponse) Descriptor() ([]byte, []int)
- func (m *BatchGetRotationsResponse) GetRotations() []*Rotation
- func (*BatchGetRotationsResponse) ProtoMessage()
- func (m *BatchGetRotationsResponse) Reset()
- func (m *BatchGetRotationsResponse) String() string
- func (m *BatchGetRotationsResponse) XXX_DiscardUnknown()
- func (m *BatchGetRotationsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *BatchGetRotationsResponse) XXX_Merge(src proto.Message)
- func (m *BatchGetRotationsResponse) XXX_Size() int
- func (m *BatchGetRotationsResponse) XXX_Unmarshal(b []byte) error
- type BatchUpdateRotationsRequest
- func (*BatchUpdateRotationsRequest) Descriptor() ([]byte, []int)
- func (m *BatchUpdateRotationsRequest) GetRequests() []*UpdateRotationRequest
- func (*BatchUpdateRotationsRequest) ProtoMessage()
- func (m *BatchUpdateRotationsRequest) Reset()
- func (m *BatchUpdateRotationsRequest) String() string
- func (m *BatchUpdateRotationsRequest) XXX_DiscardUnknown()
- func (m *BatchUpdateRotationsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *BatchUpdateRotationsRequest) XXX_Merge(src proto.Message)
- func (m *BatchUpdateRotationsRequest) XXX_Size() int
- func (m *BatchUpdateRotationsRequest) XXX_Unmarshal(b []byte) error
- type BatchUpdateRotationsResponse
- func (*BatchUpdateRotationsResponse) Descriptor() ([]byte, []int)
- func (m *BatchUpdateRotationsResponse) GetRotations() []*Rotation
- func (*BatchUpdateRotationsResponse) ProtoMessage()
- func (m *BatchUpdateRotationsResponse) Reset()
- func (m *BatchUpdateRotationsResponse) String() string
- func (m *BatchUpdateRotationsResponse) XXX_DiscardUnknown()
- func (m *BatchUpdateRotationsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *BatchUpdateRotationsResponse) XXX_Merge(src proto.Message)
- func (m *BatchUpdateRotationsResponse) XXX_Size() int
- func (m *BatchUpdateRotationsResponse) XXX_Unmarshal(b []byte) error
- type DecoratedRotationProxyService
- func (s *DecoratedRotationProxyService) BatchGetRotations(ctx context.Context, req *BatchGetRotationsRequest) (rsp *BatchGetRotationsResponse, err error)
- func (s *DecoratedRotationProxyService) BatchUpdateRotations(ctx context.Context, req *BatchUpdateRotationsRequest) (rsp *BatchUpdateRotationsResponse, err error)
- func (s *DecoratedRotationProxyService) GetRotation(ctx context.Context, req *GetRotationRequest) (rsp *Rotation, err error)
- type GetRotationRequest
- func (*GetRotationRequest) Descriptor() ([]byte, []int)
- func (m *GetRotationRequest) GetName() string
- func (*GetRotationRequest) ProtoMessage()
- func (m *GetRotationRequest) Reset()
- func (m *GetRotationRequest) String() string
- func (m *GetRotationRequest) XXX_DiscardUnknown()
- func (m *GetRotationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GetRotationRequest) XXX_Merge(src proto.Message)
- func (m *GetRotationRequest) XXX_Size() int
- func (m *GetRotationRequest) XXX_Unmarshal(b []byte) error
- type OncallPerson
- func (*OncallPerson) Descriptor() ([]byte, []int)
- func (p *OncallPerson) FromProperty(prop datastore.Property) error
- func (m *OncallPerson) GetEmail() string
- func (*OncallPerson) ProtoMessage()
- func (m *OncallPerson) Reset()
- func (m *OncallPerson) String() string
- func (p *OncallPerson) ToProperty() (prop datastore.Property, err error)
- func (m *OncallPerson) XXX_DiscardUnknown()
- func (m *OncallPerson) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *OncallPerson) XXX_Merge(src proto.Message)
- func (m *OncallPerson) XXX_Size() int
- func (m *OncallPerson) XXX_Unmarshal(b []byte) error
- type Rotation
- func (*Rotation) Descriptor() ([]byte, []int)
- func (p *Rotation) FromProperty(prop datastore.Property) error
- func (m *Rotation) GetName() string
- func (m *Rotation) GetShifts() []*Shift
- func (*Rotation) ProtoMessage()
- func (m *Rotation) Reset()
- func (m *Rotation) String() string
- func (p *Rotation) ToProperty() (prop datastore.Property, err error)
- func (m *Rotation) XXX_DiscardUnknown()
- func (m *Rotation) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *Rotation) XXX_Merge(src proto.Message)
- func (m *Rotation) XXX_Size() int
- func (m *Rotation) XXX_Unmarshal(b []byte) error
- type RotationProxyServiceClient
- type RotationProxyServiceServer
- type Shift
- func (*Shift) Descriptor() ([]byte, []int)
- func (p *Shift) FromProperty(prop datastore.Property) error
- func (m *Shift) GetEndTime() *timestamp.Timestamp
- func (m *Shift) GetOncalls() []*OncallPerson
- func (m *Shift) GetStartTime() *timestamp.Timestamp
- func (*Shift) ProtoMessage()
- func (m *Shift) Reset()
- func (m *Shift) String() string
- func (p *Shift) ToProperty() (prop datastore.Property, err error)
- func (m *Shift) XXX_DiscardUnknown()
- func (m *Shift) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *Shift) XXX_Merge(src proto.Message)
- func (m *Shift) XXX_Size() int
- func (m *Shift) XXX_Unmarshal(b []byte) error
- type UnimplementedRotationProxyServiceServer
- func (*UnimplementedRotationProxyServiceServer) BatchGetRotations(ctx context.Context, req *BatchGetRotationsRequest) (*BatchGetRotationsResponse, error)
- func (*UnimplementedRotationProxyServiceServer) BatchUpdateRotations(ctx context.Context, req *BatchUpdateRotationsRequest) (*BatchUpdateRotationsResponse, error)
- func (*UnimplementedRotationProxyServiceServer) GetRotation(ctx context.Context, req *GetRotationRequest) (*Rotation, error)
- type UpdateRotationRequest
- func (*UpdateRotationRequest) Descriptor() ([]byte, []int)
- func (m *UpdateRotationRequest) GetRotation() *Rotation
- func (*UpdateRotationRequest) ProtoMessage()
- func (m *UpdateRotationRequest) Reset()
- func (m *UpdateRotationRequest) String() string
- func (m *UpdateRotationRequest) XXX_DiscardUnknown()
- func (m *UpdateRotationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *UpdateRotationRequest) XXX_Merge(src proto.Message)
- func (m *UpdateRotationRequest) XXX_Size() int
- func (m *UpdateRotationRequest) XXX_Unmarshal(b []byte) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FileDescriptorSet ¶
func FileDescriptorSet() *descriptor.FileDescriptorSet
FileDescriptorSet returns a descriptor set for this proto package, which includes all defined services, and all transitive dependencies.
Will not return nil.
Do NOT modify the returned descriptor.
func RegisterRotationProxyServiceServer ¶
func RegisterRotationProxyServiceServer(s prpc.Registrar, srv RotationProxyServiceServer)
Types ¶
type BatchGetRotationsRequest ¶
type BatchGetRotationsRequest struct {
// The names of the rotations to fetch.
Names []string `protobuf:"bytes,1,rep,name=names,proto3" json:"names,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*BatchGetRotationsRequest) Descriptor ¶
func (*BatchGetRotationsRequest) Descriptor() ([]byte, []int)
func (*BatchGetRotationsRequest) GetNames ¶
func (m *BatchGetRotationsRequest) GetNames() []string
func (*BatchGetRotationsRequest) ProtoMessage ¶
func (*BatchGetRotationsRequest) ProtoMessage()
func (*BatchGetRotationsRequest) Reset ¶
func (m *BatchGetRotationsRequest) Reset()
func (*BatchGetRotationsRequest) String ¶
func (m *BatchGetRotationsRequest) String() string
func (*BatchGetRotationsRequest) XXX_DiscardUnknown ¶
func (m *BatchGetRotationsRequest) XXX_DiscardUnknown()
func (*BatchGetRotationsRequest) XXX_Marshal ¶
func (m *BatchGetRotationsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*BatchGetRotationsRequest) XXX_Merge ¶
func (m *BatchGetRotationsRequest) XXX_Merge(src proto.Message)
func (*BatchGetRotationsRequest) XXX_Size ¶
func (m *BatchGetRotationsRequest) XXX_Size() int
func (*BatchGetRotationsRequest) XXX_Unmarshal ¶
func (m *BatchGetRotationsRequest) XXX_Unmarshal(b []byte) error
type BatchGetRotationsResponse ¶
type BatchGetRotationsResponse struct {
// Details about the rotations requested.
Rotations []*Rotation `protobuf:"bytes,1,rep,name=rotations,proto3" json:"rotations,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*BatchGetRotationsResponse) Descriptor ¶
func (*BatchGetRotationsResponse) Descriptor() ([]byte, []int)
func (*BatchGetRotationsResponse) GetRotations ¶
func (m *BatchGetRotationsResponse) GetRotations() []*Rotation
func (*BatchGetRotationsResponse) ProtoMessage ¶
func (*BatchGetRotationsResponse) ProtoMessage()
func (*BatchGetRotationsResponse) Reset ¶
func (m *BatchGetRotationsResponse) Reset()
func (*BatchGetRotationsResponse) String ¶
func (m *BatchGetRotationsResponse) String() string
func (*BatchGetRotationsResponse) XXX_DiscardUnknown ¶
func (m *BatchGetRotationsResponse) XXX_DiscardUnknown()
func (*BatchGetRotationsResponse) XXX_Marshal ¶
func (m *BatchGetRotationsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*BatchGetRotationsResponse) XXX_Merge ¶
func (m *BatchGetRotationsResponse) XXX_Merge(src proto.Message)
func (*BatchGetRotationsResponse) XXX_Size ¶
func (m *BatchGetRotationsResponse) XXX_Size() int
func (*BatchGetRotationsResponse) XXX_Unmarshal ¶
func (m *BatchGetRotationsResponse) XXX_Unmarshal(b []byte) error
type BatchUpdateRotationsRequest ¶
type BatchUpdateRotationsRequest struct {
// The rotations to update.
Requests []*UpdateRotationRequest `protobuf:"bytes,1,rep,name=requests,proto3" json:"requests,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Request to update a list of rotations.
func (*BatchUpdateRotationsRequest) Descriptor ¶
func (*BatchUpdateRotationsRequest) Descriptor() ([]byte, []int)
func (*BatchUpdateRotationsRequest) GetRequests ¶
func (m *BatchUpdateRotationsRequest) GetRequests() []*UpdateRotationRequest
func (*BatchUpdateRotationsRequest) ProtoMessage ¶
func (*BatchUpdateRotationsRequest) ProtoMessage()
func (*BatchUpdateRotationsRequest) Reset ¶
func (m *BatchUpdateRotationsRequest) Reset()
func (*BatchUpdateRotationsRequest) String ¶
func (m *BatchUpdateRotationsRequest) String() string
func (*BatchUpdateRotationsRequest) XXX_DiscardUnknown ¶
func (m *BatchUpdateRotationsRequest) XXX_DiscardUnknown()
func (*BatchUpdateRotationsRequest) XXX_Marshal ¶
func (m *BatchUpdateRotationsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*BatchUpdateRotationsRequest) XXX_Merge ¶
func (m *BatchUpdateRotationsRequest) XXX_Merge(src proto.Message)
func (*BatchUpdateRotationsRequest) XXX_Size ¶
func (m *BatchUpdateRotationsRequest) XXX_Size() int
func (*BatchUpdateRotationsRequest) XXX_Unmarshal ¶
func (m *BatchUpdateRotationsRequest) XXX_Unmarshal(b []byte) error
type BatchUpdateRotationsResponse ¶
type BatchUpdateRotationsResponse struct {
// Rotation updated.
Rotations []*Rotation `protobuf:"bytes,1,rep,name=rotations,proto3" json:"rotations,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*BatchUpdateRotationsResponse) Descriptor ¶
func (*BatchUpdateRotationsResponse) Descriptor() ([]byte, []int)
func (*BatchUpdateRotationsResponse) GetRotations ¶
func (m *BatchUpdateRotationsResponse) GetRotations() []*Rotation
func (*BatchUpdateRotationsResponse) ProtoMessage ¶
func (*BatchUpdateRotationsResponse) ProtoMessage()
func (*BatchUpdateRotationsResponse) Reset ¶
func (m *BatchUpdateRotationsResponse) Reset()
func (*BatchUpdateRotationsResponse) String ¶
func (m *BatchUpdateRotationsResponse) String() string
func (*BatchUpdateRotationsResponse) XXX_DiscardUnknown ¶
func (m *BatchUpdateRotationsResponse) XXX_DiscardUnknown()
func (*BatchUpdateRotationsResponse) XXX_Marshal ¶
func (m *BatchUpdateRotationsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*BatchUpdateRotationsResponse) XXX_Merge ¶
func (m *BatchUpdateRotationsResponse) XXX_Merge(src proto.Message)
func (*BatchUpdateRotationsResponse) XXX_Size ¶
func (m *BatchUpdateRotationsResponse) XXX_Size() int
func (*BatchUpdateRotationsResponse) XXX_Unmarshal ¶
func (m *BatchUpdateRotationsResponse) XXX_Unmarshal(b []byte) error
type DecoratedRotationProxyService ¶
type DecoratedRotationProxyService struct {
// Service is the service to decorate.
Service RotationProxyServiceServer
// Prelude is called for each method before forwarding the call to Service.
// If Prelude returns an error, then the call is skipped and the error is
// processed via the Postlude (if one is defined), or it is returned directly.
Prelude func(ctx context.Context, methodName string, req proto.Message) (context.Context, error)
// Postlude is called for each method after Service has processed the call, or
// after the Prelude has returned an error. This takes the the Service's
// response proto (which may be nil) and/or any error. The decorated
// service will return the response (possibly mutated) and error that Postlude
// returns.
Postlude func(ctx context.Context, methodName string, rsp proto.Message, err error) error
}
func (*DecoratedRotationProxyService) BatchGetRotations ¶
func (s *DecoratedRotationProxyService) BatchGetRotations(ctx context.Context, req *BatchGetRotationsRequest) (rsp *BatchGetRotationsResponse, err error)
func (*DecoratedRotationProxyService) BatchUpdateRotations ¶
func (s *DecoratedRotationProxyService) BatchUpdateRotations(ctx context.Context, req *BatchUpdateRotationsRequest) (rsp *BatchUpdateRotationsResponse, err error)
func (*DecoratedRotationProxyService) GetRotation ¶
func (s *DecoratedRotationProxyService) GetRotation(ctx context.Context, req *GetRotationRequest) (rsp *Rotation, err error)
type GetRotationRequest ¶
type GetRotationRequest struct {
// The name of the rotation to fetch.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*GetRotationRequest) Descriptor ¶
func (*GetRotationRequest) Descriptor() ([]byte, []int)
func (*GetRotationRequest) GetName ¶
func (m *GetRotationRequest) GetName() string
func (*GetRotationRequest) ProtoMessage ¶
func (*GetRotationRequest) ProtoMessage()
func (*GetRotationRequest) Reset ¶
func (m *GetRotationRequest) Reset()
func (*GetRotationRequest) String ¶
func (m *GetRotationRequest) String() string
func (*GetRotationRequest) XXX_DiscardUnknown ¶
func (m *GetRotationRequest) XXX_DiscardUnknown()
func (*GetRotationRequest) XXX_Marshal ¶
func (m *GetRotationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GetRotationRequest) XXX_Merge ¶
func (m *GetRotationRequest) XXX_Merge(src proto.Message)
func (*GetRotationRequest) XXX_Size ¶
func (m *GetRotationRequest) XXX_Size() int
func (*GetRotationRequest) XXX_Unmarshal ¶
func (m *GetRotationRequest) XXX_Unmarshal(b []byte) error
type OncallPerson ¶
type OncallPerson struct {
// Email of oncall person.
Email string `protobuf:"bytes,1,opt,name=email,proto3" json:"email,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*OncallPerson) Descriptor ¶
func (*OncallPerson) Descriptor() ([]byte, []int)
func (*OncallPerson) FromProperty ¶
func (p *OncallPerson) FromProperty(prop datastore.Property) error
FromProperty implements datastore.PropertyConverter. It parses a '[]byte' into an embedded 'OncallPerson' when used with the "go.chromium.org/luci/gae" library.
func (*OncallPerson) GetEmail ¶
func (m *OncallPerson) GetEmail() string
func (*OncallPerson) ProtoMessage ¶
func (*OncallPerson) ProtoMessage()
func (*OncallPerson) Reset ¶
func (m *OncallPerson) Reset()
func (*OncallPerson) String ¶
func (m *OncallPerson) String() string
func (*OncallPerson) ToProperty ¶
func (p *OncallPerson) ToProperty() (prop datastore.Property, err error)
ToProperty implements datastore.PropertyConverter. It causes an embedded 'OncallPerson' to serialize to an unindexed '[]byte' when used with the "go.chromium.org/luci/gae" library.
func (*OncallPerson) XXX_DiscardUnknown ¶
func (m *OncallPerson) XXX_DiscardUnknown()
func (*OncallPerson) XXX_Marshal ¶
func (m *OncallPerson) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*OncallPerson) XXX_Merge ¶
func (m *OncallPerson) XXX_Merge(src proto.Message)
func (*OncallPerson) XXX_Size ¶
func (m *OncallPerson) XXX_Size() int
func (*OncallPerson) XXX_Unmarshal ¶
func (m *OncallPerson) XXX_Unmarshal(b []byte) error
type Rotation ¶
type Rotation struct {
// The unique name of the rotation.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Shifts in a rotation.
// Shifts will be sorted by start time with the current shift as the first element.
Shifts []*Shift `protobuf:"bytes,2,rep,name=shifts,proto3" json:"shifts,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Contains information about a rotation.
func (*Rotation) Descriptor ¶
func (*Rotation) FromProperty ¶
FromProperty implements datastore.PropertyConverter. It parses a '[]byte' into an embedded 'Rotation' when used with the "go.chromium.org/luci/gae" library.
func (*Rotation) ProtoMessage ¶
func (*Rotation) ProtoMessage()
func (*Rotation) ToProperty ¶
ToProperty implements datastore.PropertyConverter. It causes an embedded 'Rotation' to serialize to an unindexed '[]byte' when used with the "go.chromium.org/luci/gae" library.
func (*Rotation) XXX_DiscardUnknown ¶
func (m *Rotation) XXX_DiscardUnknown()
func (*Rotation) XXX_Marshal ¶
func (*Rotation) XXX_Unmarshal ¶
type RotationProxyServiceClient ¶
type RotationProxyServiceClient interface {
BatchUpdateRotations(ctx context.Context, in *BatchUpdateRotationsRequest, opts ...grpc.CallOption) (*BatchUpdateRotationsResponse, error)
GetRotation(ctx context.Context, in *GetRotationRequest, opts ...grpc.CallOption) (*Rotation, error)
BatchGetRotations(ctx context.Context, in *BatchGetRotationsRequest, opts ...grpc.CallOption) (*BatchGetRotationsResponse, error)
}
RotationProxyServiceClient is the client API for RotationProxyService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewRotationProxyServiceClient ¶
func NewRotationProxyServiceClient(cc grpc.ClientConnInterface) RotationProxyServiceClient
func NewRotationProxyServicePRPCClient ¶
func NewRotationProxyServicePRPCClient(client *prpc.Client) RotationProxyServiceClient
type RotationProxyServiceServer ¶
type RotationProxyServiceServer interface {
BatchUpdateRotations(context.Context, *BatchUpdateRotationsRequest) (*BatchUpdateRotationsResponse, error)
GetRotation(context.Context, *GetRotationRequest) (*Rotation, error)
BatchGetRotations(context.Context, *BatchGetRotationsRequest) (*BatchGetRotationsResponse, error)
}
RotationProxyServiceServer is the server API for RotationProxyService service.
type Shift ¶
type Shift struct {
// The list of oncall users for this shift.
Oncalls []*OncallPerson `protobuf:"bytes,1,rep,name=oncalls,proto3" json:"oncalls,omitempty"`
// Timestamp of the start of the shift.
StartTime *timestamp.Timestamp `protobuf:"bytes,2,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
// Timestamp of the end of the shift.
EndTime *timestamp.Timestamp `protobuf:"bytes,3,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*Shift) Descriptor ¶
func (*Shift) FromProperty ¶
FromProperty implements datastore.PropertyConverter. It parses a '[]byte' into an embedded 'Shift' when used with the "go.chromium.org/luci/gae" library.
func (*Shift) GetEndTime ¶
func (*Shift) GetOncalls ¶
func (m *Shift) GetOncalls() []*OncallPerson
func (*Shift) GetStartTime ¶
func (*Shift) ProtoMessage ¶
func (*Shift) ProtoMessage()
func (*Shift) ToProperty ¶
ToProperty implements datastore.PropertyConverter. It causes an embedded 'Shift' to serialize to an unindexed '[]byte' when used with the "go.chromium.org/luci/gae" library.
func (*Shift) XXX_DiscardUnknown ¶
func (m *Shift) XXX_DiscardUnknown()
func (*Shift) XXX_Marshal ¶
func (*Shift) XXX_Unmarshal ¶
type UnimplementedRotationProxyServiceServer ¶
type UnimplementedRotationProxyServiceServer struct {
}
UnimplementedRotationProxyServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedRotationProxyServiceServer) BatchGetRotations ¶
func (*UnimplementedRotationProxyServiceServer) BatchGetRotations(ctx context.Context, req *BatchGetRotationsRequest) (*BatchGetRotationsResponse, error)
func (*UnimplementedRotationProxyServiceServer) BatchUpdateRotations ¶
func (*UnimplementedRotationProxyServiceServer) BatchUpdateRotations(ctx context.Context, req *BatchUpdateRotationsRequest) (*BatchUpdateRotationsResponse, error)
func (*UnimplementedRotationProxyServiceServer) GetRotation ¶
func (*UnimplementedRotationProxyServiceServer) GetRotation(ctx context.Context, req *GetRotationRequest) (*Rotation, error)
type UpdateRotationRequest ¶
type UpdateRotationRequest struct {
// The rotation to update.
Rotation *Rotation `protobuf:"bytes,1,opt,name=rotation,proto3" json:"rotation,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*UpdateRotationRequest) Descriptor ¶
func (*UpdateRotationRequest) Descriptor() ([]byte, []int)
func (*UpdateRotationRequest) GetRotation ¶
func (m *UpdateRotationRequest) GetRotation() *Rotation
func (*UpdateRotationRequest) ProtoMessage ¶
func (*UpdateRotationRequest) ProtoMessage()
func (*UpdateRotationRequest) Reset ¶
func (m *UpdateRotationRequest) Reset()
func (*UpdateRotationRequest) String ¶
func (m *UpdateRotationRequest) String() string
func (*UpdateRotationRequest) XXX_DiscardUnknown ¶
func (m *UpdateRotationRequest) XXX_DiscardUnknown()
func (*UpdateRotationRequest) XXX_Marshal ¶
func (m *UpdateRotationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*UpdateRotationRequest) XXX_Merge ¶
func (m *UpdateRotationRequest) XXX_Merge(src proto.Message)
func (*UpdateRotationRequest) XXX_Size ¶
func (m *UpdateRotationRequest) XXX_Size() int
func (*UpdateRotationRequest) XXX_Unmarshal ¶
func (m *UpdateRotationRequest) XXX_Unmarshal(b []byte) error