Documentation
¶
Index ¶
- Variables
- type ChangeReviewTask
- func (*ChangeReviewTask) Descriptor() ([]byte, []int)deprecated
- func (x *ChangeReviewTask) GetAutoSubmit() bool
- func (x *ChangeReviewTask) GetCherryPickOfChange() int64
- func (x *ChangeReviewTask) GetCreated() *timestamppb.Timestamp
- func (x *ChangeReviewTask) GetHost() string
- func (x *ChangeReviewTask) GetNumber() int64
- func (x *ChangeReviewTask) GetRepo() string
- func (x *ChangeReviewTask) GetRevertOf() int64
- func (x *ChangeReviewTask) GetRevision() string
- func (x *ChangeReviewTask) GetRevisionsCount() int64
- func (*ChangeReviewTask) ProtoMessage()
- func (x *ChangeReviewTask) ProtoReflect() protoreflect.Message
- func (x *ChangeReviewTask) Reset()
- func (x *ChangeReviewTask) String() string
Constants ¶
This section is empty.
Variables ¶
var File_infra_appengine_rubber_stamper_tasks_taskspb_tasks_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ChangeReviewTask ¶
type ChangeReviewTask struct {
// The Gerrit Host.
Host string `protobuf:"bytes,1,opt,name=host,proto3" json:"host,omitempty"`
// The change number.
Number int64 `protobuf:"varint,2,opt,name=number,proto3" json:"number,omitempty"`
// Current revision of the change.
Revision string `protobuf:"bytes,3,opt,name=revision,proto3" json:"revision,omitempty"`
// The Gerrit Repo.
Repo string `protobuf:"bytes,4,opt,name=repo,proto3" json:"repo,omitempty"`
// Whether the change has Auto-Submit label.
AutoSubmit bool `protobuf:"varint,5,opt,name=auto_submit,json=autoSubmit,proto3" json:"auto_submit,omitempty"`
// The numeric Change-Id of the change that this change reverts.
RevertOf int64 `protobuf:"varint,6,opt,name=revert_of,json=revertOf,proto3" json:"revert_of,omitempty"`
// The numeric Change-Id of the change that this change was cherry-picked
// from.
CherryPickOfChange int64 `protobuf:"varint,7,opt,name=cherry_pick_of_change,json=cherryPickOfChange,proto3" json:"cherry_pick_of_change,omitempty"`
// The number of revisions.
RevisionsCount int64 `protobuf:"varint,8,opt,name=revisions_count,json=revisionsCount,proto3" json:"revisions_count,omitempty"`
// Timestamp of when the change was created.
Created *timestamppb.Timestamp `protobuf:"bytes,11,opt,name=created,proto3" json:"created,omitempty"`
// contains filtered or unexported fields
}
ChangeReviewTask describes a task to start reviewing a CL's metadata.
func (*ChangeReviewTask) Descriptor
deprecated
func (*ChangeReviewTask) Descriptor() ([]byte, []int)
Deprecated: Use ChangeReviewTask.ProtoReflect.Descriptor instead.
func (*ChangeReviewTask) GetAutoSubmit ¶
func (x *ChangeReviewTask) GetAutoSubmit() bool
func (*ChangeReviewTask) GetCherryPickOfChange ¶
func (x *ChangeReviewTask) GetCherryPickOfChange() int64
func (*ChangeReviewTask) GetCreated ¶
func (x *ChangeReviewTask) GetCreated() *timestamppb.Timestamp
func (*ChangeReviewTask) GetHost ¶
func (x *ChangeReviewTask) GetHost() string
func (*ChangeReviewTask) GetNumber ¶
func (x *ChangeReviewTask) GetNumber() int64
func (*ChangeReviewTask) GetRepo ¶
func (x *ChangeReviewTask) GetRepo() string
func (*ChangeReviewTask) GetRevertOf ¶
func (x *ChangeReviewTask) GetRevertOf() int64
func (*ChangeReviewTask) GetRevision ¶
func (x *ChangeReviewTask) GetRevision() string
func (*ChangeReviewTask) GetRevisionsCount ¶
func (x *ChangeReviewTask) GetRevisionsCount() int64
func (*ChangeReviewTask) ProtoMessage ¶
func (*ChangeReviewTask) ProtoMessage()
func (*ChangeReviewTask) ProtoReflect ¶
func (x *ChangeReviewTask) ProtoReflect() protoreflect.Message
func (*ChangeReviewTask) Reset ¶
func (x *ChangeReviewTask) Reset()
func (*ChangeReviewTask) String ¶
func (x *ChangeReviewTask) String() string
Click to show internal directories.
Click to hide internal directories.