Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ArtifactLink ¶
type ArtifactLink struct {
// Name is the name of the artifact.
Name string `json:"name"`
// Location is the location of the artifact.
Location string `json:"location"`
}
ArtifactLink is a link to a test artifact left by perf tests.
type TestWithResult ¶
type TestWithResult struct {
TestName string `json:"test_name"`
IsFlaky bool `json:"is_flaky"`
SuspectedCLs []messages.SuspectCL `json:"suspected_cls"`
Expectations []*te.ExpectationStatement `json:"expectations"`
Artifacts []ArtifactLink `json:"artifacts"`
}
TestWithResult stores the information provided by Findit for a specific test, for example if the test is flaky or is there a culprit for the test failure. Also contains test-specific details like expectations and any artifacts produced by the test run.
Click to show internal directories.
Click to hide internal directories.