Documentation
¶
Index ¶
- Variables
- type SOMAlertsEvent
- func (*SOMAlertsEvent) Descriptor() ([]byte, []int)deprecated
- func (x *SOMAlertsEvent) GetAlerts() []*SOMAlertsEvent_Alert
- func (x *SOMAlertsEvent) GetRequestId() string
- func (x *SOMAlertsEvent) GetTimestamp() *timestamppb.Timestamp
- func (x *SOMAlertsEvent) GetTree() string
- func (*SOMAlertsEvent) ProtoMessage()
- func (x *SOMAlertsEvent) ProtoReflect() protoreflect.Message
- func (x *SOMAlertsEvent) Reset()
- func (x *SOMAlertsEvent) String() string
- type SOMAlertsEvent_Alert
- func (*SOMAlertsEvent_Alert) Descriptor() ([]byte, []int)deprecated
- func (x *SOMAlertsEvent_Alert) GetBody() string
- func (x *SOMAlertsEvent_Alert) GetBuildbotFailures() []*SOMAlertsEvent_Alert_BuildbotFailure
- func (x *SOMAlertsEvent_Alert) GetKey() string
- func (x *SOMAlertsEvent_Alert) GetTitle() string
- func (x *SOMAlertsEvent_Alert) GetType() SOMAlertsEvent_Alert_AlertType
- func (*SOMAlertsEvent_Alert) ProtoMessage()
- func (x *SOMAlertsEvent_Alert) ProtoReflect() protoreflect.Message
- func (x *SOMAlertsEvent_Alert) Reset()
- func (x *SOMAlertsEvent_Alert) String() string
- type SOMAlertsEvent_Alert_AlertType
- func (SOMAlertsEvent_Alert_AlertType) Descriptor() protoreflect.EnumDescriptor
- func (x SOMAlertsEvent_Alert_AlertType) Enum() *SOMAlertsEvent_Alert_AlertType
- func (SOMAlertsEvent_Alert_AlertType) EnumDescriptor() ([]byte, []int)deprecated
- func (x SOMAlertsEvent_Alert_AlertType) Number() protoreflect.EnumNumber
- func (x SOMAlertsEvent_Alert_AlertType) String() string
- func (SOMAlertsEvent_Alert_AlertType) Type() protoreflect.EnumType
- type SOMAlertsEvent_Alert_BuildbotFailure
- func (*SOMAlertsEvent_Alert_BuildbotFailure) Descriptor() ([]byte, []int)deprecated
- func (x *SOMAlertsEvent_Alert_BuildbotFailure) GetBuilder() string
- func (x *SOMAlertsEvent_Alert_BuildbotFailure) GetBuilderGroup() string
- func (x *SOMAlertsEvent_Alert_BuildbotFailure) GetFirstFailure() int64
- func (x *SOMAlertsEvent_Alert_BuildbotFailure) GetLatestFailure() int64
- func (x *SOMAlertsEvent_Alert_BuildbotFailure) GetLatestPassing() int64
- func (x *SOMAlertsEvent_Alert_BuildbotFailure) GetStep() string
- func (*SOMAlertsEvent_Alert_BuildbotFailure) ProtoMessage()
- func (x *SOMAlertsEvent_Alert_BuildbotFailure) ProtoReflect() protoreflect.Message
- func (x *SOMAlertsEvent_Alert_BuildbotFailure) Reset()
- func (x *SOMAlertsEvent_Alert_BuildbotFailure) String() string
- type SOMAnnotationEvent
- func (*SOMAnnotationEvent) Descriptor() ([]byte, []int)deprecated
- func (x *SOMAnnotationEvent) GetAlertKey() string
- func (x *SOMAnnotationEvent) GetAlertKeyDigest() string
- func (x *SOMAnnotationEvent) GetBugList() []*SOMAnnotationEvent_MonorailBug
- func (x *SOMAnnotationEvent) GetBugs() []stringdeprecated
- func (x *SOMAnnotationEvent) GetComments() []*SOMAnnotationEvent_Comment
- func (x *SOMAnnotationEvent) GetGroupId() string
- func (x *SOMAnnotationEvent) GetModificationTime() *timestamppb.Timestamp
- func (x *SOMAnnotationEvent) GetOperation() SOMAnnotationEvent_OperationType
- func (x *SOMAnnotationEvent) GetRequestId() string
- func (x *SOMAnnotationEvent) GetSnoozeTime() *timestamppb.Timestamp
- func (x *SOMAnnotationEvent) GetTimestamp() *timestamppb.Timestamp
- func (x *SOMAnnotationEvent) GetTree() string
- func (x *SOMAnnotationEvent) GetUser() string
- func (*SOMAnnotationEvent) ProtoMessage()
- func (x *SOMAnnotationEvent) ProtoReflect() protoreflect.Message
- func (x *SOMAnnotationEvent) Reset()
- func (x *SOMAnnotationEvent) String() string
- type SOMAnnotationEvent_Comment
- func (*SOMAnnotationEvent_Comment) Descriptor() ([]byte, []int)deprecated
- func (x *SOMAnnotationEvent_Comment) GetText() string
- func (x *SOMAnnotationEvent_Comment) GetTime() *timestamppb.Timestamp
- func (*SOMAnnotationEvent_Comment) ProtoMessage()
- func (x *SOMAnnotationEvent_Comment) ProtoReflect() protoreflect.Message
- func (x *SOMAnnotationEvent_Comment) Reset()
- func (x *SOMAnnotationEvent_Comment) String() string
- type SOMAnnotationEvent_MonorailBug
- func (*SOMAnnotationEvent_MonorailBug) Descriptor() ([]byte, []int)deprecated
- func (x *SOMAnnotationEvent_MonorailBug) GetBugId() string
- func (x *SOMAnnotationEvent_MonorailBug) GetProjectId() string
- func (*SOMAnnotationEvent_MonorailBug) ProtoMessage()
- func (x *SOMAnnotationEvent_MonorailBug) ProtoReflect() protoreflect.Message
- func (x *SOMAnnotationEvent_MonorailBug) Reset()
- func (x *SOMAnnotationEvent_MonorailBug) String() string
- type SOMAnnotationEvent_OperationType
- func (SOMAnnotationEvent_OperationType) Descriptor() protoreflect.EnumDescriptor
- func (x SOMAnnotationEvent_OperationType) Enum() *SOMAnnotationEvent_OperationType
- func (SOMAnnotationEvent_OperationType) EnumDescriptor() ([]byte, []int)deprecated
- func (x SOMAnnotationEvent_OperationType) Number() protoreflect.EnumNumber
- func (x SOMAnnotationEvent_OperationType) String() string
- func (SOMAnnotationEvent_OperationType) Type() protoreflect.EnumType
Constants ¶
This section is empty.
Variables ¶
var ( SOMAlertsEvent_Alert_AlertType_name = map[int32]string{ 0: "UNUSED", 1: "HUNG_BUILDER", 2: "OFFLINE_BUILDER", 3: "IDLE_BUILDER", 4: "INFRA_FAILURE", 5: "BUILD_FAILURE", 6: "TEST_FAILURE", } SOMAlertsEvent_Alert_AlertType_value = map[string]int32{ "UNUSED": 0, "HUNG_BUILDER": 1, "OFFLINE_BUILDER": 2, "IDLE_BUILDER": 3, "INFRA_FAILURE": 4, "BUILD_FAILURE": 5, "TEST_FAILURE": 6, } )
Enum value maps for SOMAlertsEvent_Alert_AlertType.
var ( SOMAnnotationEvent_OperationType_name = map[int32]string{ 0: "ADD", 1: "DELETE", } SOMAnnotationEvent_OperationType_value = map[string]int32{ "ADD": 0, "DELETE": 1, } )
Enum value maps for SOMAnnotationEvent_OperationType.
var File_infra_appengine_sheriff_o_matic_som_model_gen_events_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type SOMAlertsEvent ¶
type SOMAlertsEvent struct {
// Tree is the name of the tree.
Tree string `protobuf:"bytes,1,opt,name=tree,proto3" json:"tree,omitempty"`
// Timestamp is when the alerts were generated.
Timestamp *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
// RequestId is the id of the incoming http request for the cron handler
// that generated these alerts. This ID appears in the GAE request logs as
// protoPayload.requestId.
RequestId string `protobuf:"bytes,3,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// Alerts are the set of alerts generated by an analyzer cron job run.
Alerts []*SOMAlertsEvent_Alert `protobuf:"bytes,4,rep,name=Alerts,proto3" json:"Alerts,omitempty"`
// contains filtered or unexported fields
}
Alerts contains alerts generated by sheriff-o-matic analyzer cron jobs.
func (*SOMAlertsEvent) Descriptor
deprecated
func (*SOMAlertsEvent) Descriptor() ([]byte, []int)
Deprecated: Use SOMAlertsEvent.ProtoReflect.Descriptor instead.
func (*SOMAlertsEvent) GetAlerts ¶
func (x *SOMAlertsEvent) GetAlerts() []*SOMAlertsEvent_Alert
func (*SOMAlertsEvent) GetRequestId ¶
func (x *SOMAlertsEvent) GetRequestId() string
func (*SOMAlertsEvent) GetTimestamp ¶
func (x *SOMAlertsEvent) GetTimestamp() *timestamppb.Timestamp
func (*SOMAlertsEvent) GetTree ¶
func (x *SOMAlertsEvent) GetTree() string
func (*SOMAlertsEvent) ProtoMessage ¶
func (*SOMAlertsEvent) ProtoMessage()
func (*SOMAlertsEvent) ProtoReflect ¶
func (x *SOMAlertsEvent) ProtoReflect() protoreflect.Message
func (*SOMAlertsEvent) Reset ¶
func (x *SOMAlertsEvent) Reset()
func (*SOMAlertsEvent) String ¶
func (x *SOMAlertsEvent) String() string
type SOMAlertsEvent_Alert ¶
type SOMAlertsEvent_Alert struct {
// Key is an opaque key generated for each alert.
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// Title is the human-readable title of the alert.
Title string `protobuf:"bytes,2,opt,name=title,proto3" json:"title,omitempty"`
// Body is the human-readable plain text body of the alert.
Body string `protobuf:"bytes,3,opt,name=body,proto3" json:"body,omitempty"`
// Type is the type of alert.
Type SOMAlertsEvent_Alert_AlertType `protobuf:"varint,4,opt,name=type,proto3,enum=som.events.SOMAlertsEvent_Alert_AlertType" json:"type,omitempty"`
// BuildbotFailures contains information about build failures grouped into this alert.
BuildbotFailures []*SOMAlertsEvent_Alert_BuildbotFailure `protobuf:"bytes,6,rep,name=buildbot_failures,json=buildbotFailures,proto3" json:"buildbot_failures,omitempty"`
// contains filtered or unexported fields
}
func (*SOMAlertsEvent_Alert) Descriptor
deprecated
func (*SOMAlertsEvent_Alert) Descriptor() ([]byte, []int)
Deprecated: Use SOMAlertsEvent_Alert.ProtoReflect.Descriptor instead.
func (*SOMAlertsEvent_Alert) GetBody ¶
func (x *SOMAlertsEvent_Alert) GetBody() string
func (*SOMAlertsEvent_Alert) GetBuildbotFailures ¶
func (x *SOMAlertsEvent_Alert) GetBuildbotFailures() []*SOMAlertsEvent_Alert_BuildbotFailure
func (*SOMAlertsEvent_Alert) GetKey ¶
func (x *SOMAlertsEvent_Alert) GetKey() string
func (*SOMAlertsEvent_Alert) GetTitle ¶
func (x *SOMAlertsEvent_Alert) GetTitle() string
func (*SOMAlertsEvent_Alert) GetType ¶
func (x *SOMAlertsEvent_Alert) GetType() SOMAlertsEvent_Alert_AlertType
func (*SOMAlertsEvent_Alert) ProtoMessage ¶
func (*SOMAlertsEvent_Alert) ProtoMessage()
func (*SOMAlertsEvent_Alert) ProtoReflect ¶
func (x *SOMAlertsEvent_Alert) ProtoReflect() protoreflect.Message
func (*SOMAlertsEvent_Alert) Reset ¶
func (x *SOMAlertsEvent_Alert) Reset()
func (*SOMAlertsEvent_Alert) String ¶
func (x *SOMAlertsEvent_Alert) String() string
type SOMAlertsEvent_Alert_AlertType ¶
type SOMAlertsEvent_Alert_AlertType int32
AlertType is the type of alert, from AlertType constants in infra/monitoring/messages/alerts.go. Until those constants are replaced in the analyzer code with these enum values, this list will have to be manually kept in sync.
const ( // This should not be used. It is here as a result of deleting some unused // values, and in proto3, the first enum value must be zero SOMAlertsEvent_Alert_UNUSED SOMAlertsEvent_Alert_AlertType = 0 // HUNG_BUILDER indicates that a builder has been executing a step for too long. SOMAlertsEvent_Alert_HUNG_BUILDER SOMAlertsEvent_Alert_AlertType = 1 // OFFLINE_BUILDER indicates that we have no recent updates from the builder. SOMAlertsEvent_Alert_OFFLINE_BUILDER SOMAlertsEvent_Alert_AlertType = 2 // IDLE_BUILDER indicates that a builder has not executed any builds recently // even though it has requests queued up. SOMAlertsEvent_Alert_IDLE_BUILDER SOMAlertsEvent_Alert_AlertType = 3 // INFRA_FAILURE indicates that a builder step failed due to infrastructure. SOMAlertsEvent_Alert_INFRA_FAILURE SOMAlertsEvent_Alert_AlertType = 4 // BUILD_FAILURE indicates that one of the build steps failed, most likely // due to the patch it's building/running with. SOMAlertsEvent_Alert_BUILD_FAILURE SOMAlertsEvent_Alert_AlertType = 5 // TEST_FAILURE indicates that one or more of the tests in the build failed. SOMAlertsEvent_Alert_TEST_FAILURE SOMAlertsEvent_Alert_AlertType = 6 )
func (SOMAlertsEvent_Alert_AlertType) Descriptor ¶
func (SOMAlertsEvent_Alert_AlertType) Descriptor() protoreflect.EnumDescriptor
func (SOMAlertsEvent_Alert_AlertType) Enum ¶
func (x SOMAlertsEvent_Alert_AlertType) Enum() *SOMAlertsEvent_Alert_AlertType
func (SOMAlertsEvent_Alert_AlertType) EnumDescriptor
deprecated
func (SOMAlertsEvent_Alert_AlertType) EnumDescriptor() ([]byte, []int)
Deprecated: Use SOMAlertsEvent_Alert_AlertType.Descriptor instead.
func (SOMAlertsEvent_Alert_AlertType) Number ¶
func (x SOMAlertsEvent_Alert_AlertType) Number() protoreflect.EnumNumber
func (SOMAlertsEvent_Alert_AlertType) String ¶
func (x SOMAlertsEvent_Alert_AlertType) String() string
func (SOMAlertsEvent_Alert_AlertType) Type ¶
func (SOMAlertsEvent_Alert_AlertType) Type() protoreflect.EnumType
type SOMAlertsEvent_Alert_BuildbotFailure ¶
type SOMAlertsEvent_Alert_BuildbotFailure struct {
// Builder group is the name of the buildbot builder group.
BuilderGroup string `protobuf:"bytes,1,opt,name=builder_group,json=builderGroup,proto3" json:"builder_group,omitempty"`
// Builder is the name of the builder.
Builder string `protobuf:"bytes,2,opt,name=builder,proto3" json:"builder,omitempty"`
// Step is the name of the failing build step.
Step string `protobuf:"bytes,3,opt,name=step,proto3" json:"step,omitempty"`
// FirstFailure is the eariest known build number for this run of failures.
FirstFailure int64 `protobuf:"varint,4,opt,name=first_failure,json=firstFailure,proto3" json:"first_failure,omitempty"`
// LatestFailure is the latest known build number for this run of failures.
LatestFailure int64 `protobuf:"varint,5,opt,name=latest_failure,json=latestFailure,proto3" json:"latest_failure,omitempty"`
// LatestPassing is the latest known build number where this step passed.
LatestPassing int64 `protobuf:"varint,6,opt,name=latest_passing,json=latestPassing,proto3" json:"latest_passing,omitempty"`
// contains filtered or unexported fields
}
BuildBotFaiure describes a range of failing builds on a buildbot builder.
func (*SOMAlertsEvent_Alert_BuildbotFailure) Descriptor
deprecated
func (*SOMAlertsEvent_Alert_BuildbotFailure) Descriptor() ([]byte, []int)
Deprecated: Use SOMAlertsEvent_Alert_BuildbotFailure.ProtoReflect.Descriptor instead.
func (*SOMAlertsEvent_Alert_BuildbotFailure) GetBuilder ¶
func (x *SOMAlertsEvent_Alert_BuildbotFailure) GetBuilder() string
func (*SOMAlertsEvent_Alert_BuildbotFailure) GetBuilderGroup ¶
func (x *SOMAlertsEvent_Alert_BuildbotFailure) GetBuilderGroup() string
func (*SOMAlertsEvent_Alert_BuildbotFailure) GetFirstFailure ¶
func (x *SOMAlertsEvent_Alert_BuildbotFailure) GetFirstFailure() int64
func (*SOMAlertsEvent_Alert_BuildbotFailure) GetLatestFailure ¶
func (x *SOMAlertsEvent_Alert_BuildbotFailure) GetLatestFailure() int64
func (*SOMAlertsEvent_Alert_BuildbotFailure) GetLatestPassing ¶
func (x *SOMAlertsEvent_Alert_BuildbotFailure) GetLatestPassing() int64
func (*SOMAlertsEvent_Alert_BuildbotFailure) GetStep ¶
func (x *SOMAlertsEvent_Alert_BuildbotFailure) GetStep() string
func (*SOMAlertsEvent_Alert_BuildbotFailure) ProtoMessage ¶
func (*SOMAlertsEvent_Alert_BuildbotFailure) ProtoMessage()
func (*SOMAlertsEvent_Alert_BuildbotFailure) ProtoReflect ¶
func (x *SOMAlertsEvent_Alert_BuildbotFailure) ProtoReflect() protoreflect.Message
func (*SOMAlertsEvent_Alert_BuildbotFailure) Reset ¶
func (x *SOMAlertsEvent_Alert_BuildbotFailure) Reset()
func (*SOMAlertsEvent_Alert_BuildbotFailure) String ¶
func (x *SOMAlertsEvent_Alert_BuildbotFailure) String() string
type SOMAnnotationEvent ¶
type SOMAnnotationEvent struct {
// Tree is the name of the tree.
Tree string `protobuf:"bytes,1,opt,name=tree,proto3" json:"tree,omitempty"`
// Timestamp is when the alerts were generated.
Timestamp *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
// RequestId is the id of the incoming http request that generated this
// annotation. This ID appears in the GAE request logs as protoPayload.requestId.
RequestId string `protobuf:"bytes,3,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// User is the ID of the user making the annotation change.
User string `protobuf:"bytes,4,opt,name=user,proto3" json:"user,omitempty"`
// AlertKeyDigest is the key digest for the alert.
AlertKeyDigest string `protobuf:"bytes,5,opt,name=alert_key_digest,json=alertKeyDigest,proto3" json:"alert_key_digest,omitempty"`
// AlertKey is an opaque key for the alert being annotated.
AlertKey string `protobuf:"bytes,6,opt,name=alert_key,json=alertKey,proto3" json:"alert_key,omitempty"`
// Operation is the annoation operation.
Operation SOMAnnotationEvent_OperationType `protobuf:"varint,7,opt,name=operation,proto3,enum=som.events.SOMAnnotationEvent_OperationType" json:"operation,omitempty"`
// Deprecated, use bug_list instead
//
// Deprecated: Do not use.
Bugs []string `protobuf:"bytes,8,rep,name=bugs,proto3" json:"bugs,omitempty"`
// bug_list is the list of MonorailBugs attached to the alert.
BugList []*SOMAnnotationEvent_MonorailBug `protobuf:"bytes,13,rep,name=bug_list,json=bugList,proto3" json:"bug_list,omitempty"`
// Comments is the list of comments attached to the alert.
Comments []*SOMAnnotationEvent_Comment `protobuf:"bytes,9,rep,name=comments,proto3" json:"comments,omitempty"`
// SnoozeTime is the time until which to snooze the alert.
SnoozeTime *timestamppb.Timestamp `protobuf:"bytes,10,opt,name=snooze_time,json=snoozeTime,proto3" json:"snooze_time,omitempty"`
// GroupId is the name of the alert group to which the alert belongs.
GroupId string `protobuf:"bytes,11,opt,name=group_id,json=groupId,proto3" json:"group_id,omitempty"`
// ModificationTime is the time the annotation was modified.
ModificationTime *timestamppb.Timestamp `protobuf:"bytes,12,opt,name=modification_time,json=modificationTime,proto3" json:"modification_time,omitempty"`
// contains filtered or unexported fields
}
func (*SOMAnnotationEvent) Descriptor
deprecated
func (*SOMAnnotationEvent) Descriptor() ([]byte, []int)
Deprecated: Use SOMAnnotationEvent.ProtoReflect.Descriptor instead.
func (*SOMAnnotationEvent) GetAlertKey ¶
func (x *SOMAnnotationEvent) GetAlertKey() string
func (*SOMAnnotationEvent) GetAlertKeyDigest ¶
func (x *SOMAnnotationEvent) GetAlertKeyDigest() string
func (*SOMAnnotationEvent) GetBugList ¶
func (x *SOMAnnotationEvent) GetBugList() []*SOMAnnotationEvent_MonorailBug
func (*SOMAnnotationEvent) GetBugs
deprecated
func (x *SOMAnnotationEvent) GetBugs() []string
Deprecated: Do not use.
func (*SOMAnnotationEvent) GetComments ¶
func (x *SOMAnnotationEvent) GetComments() []*SOMAnnotationEvent_Comment
func (*SOMAnnotationEvent) GetGroupId ¶
func (x *SOMAnnotationEvent) GetGroupId() string
func (*SOMAnnotationEvent) GetModificationTime ¶
func (x *SOMAnnotationEvent) GetModificationTime() *timestamppb.Timestamp
func (*SOMAnnotationEvent) GetOperation ¶
func (x *SOMAnnotationEvent) GetOperation() SOMAnnotationEvent_OperationType
func (*SOMAnnotationEvent) GetRequestId ¶
func (x *SOMAnnotationEvent) GetRequestId() string
func (*SOMAnnotationEvent) GetSnoozeTime ¶
func (x *SOMAnnotationEvent) GetSnoozeTime() *timestamppb.Timestamp
func (*SOMAnnotationEvent) GetTimestamp ¶
func (x *SOMAnnotationEvent) GetTimestamp() *timestamppb.Timestamp
func (*SOMAnnotationEvent) GetTree ¶
func (x *SOMAnnotationEvent) GetTree() string
func (*SOMAnnotationEvent) GetUser ¶
func (x *SOMAnnotationEvent) GetUser() string
func (*SOMAnnotationEvent) ProtoMessage ¶
func (*SOMAnnotationEvent) ProtoMessage()
func (*SOMAnnotationEvent) ProtoReflect ¶
func (x *SOMAnnotationEvent) ProtoReflect() protoreflect.Message
func (*SOMAnnotationEvent) Reset ¶
func (x *SOMAnnotationEvent) Reset()
func (*SOMAnnotationEvent) String ¶
func (x *SOMAnnotationEvent) String() string
type SOMAnnotationEvent_Comment ¶
type SOMAnnotationEvent_Comment struct {
// Text is the text of the comment.
Text string `protobuf:"bytes,1,opt,name=text,proto3" json:"text,omitempty"`
// Time is the time when the comment was posted.
Time *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=time,proto3" json:"time,omitempty"`
// contains filtered or unexported fields
}
Comment is a user comment attached to an alert.
func (*SOMAnnotationEvent_Comment) Descriptor
deprecated
func (*SOMAnnotationEvent_Comment) Descriptor() ([]byte, []int)
Deprecated: Use SOMAnnotationEvent_Comment.ProtoReflect.Descriptor instead.
func (*SOMAnnotationEvent_Comment) GetText ¶
func (x *SOMAnnotationEvent_Comment) GetText() string
func (*SOMAnnotationEvent_Comment) GetTime ¶
func (x *SOMAnnotationEvent_Comment) GetTime() *timestamppb.Timestamp
func (*SOMAnnotationEvent_Comment) ProtoMessage ¶
func (*SOMAnnotationEvent_Comment) ProtoMessage()
func (*SOMAnnotationEvent_Comment) ProtoReflect ¶
func (x *SOMAnnotationEvent_Comment) ProtoReflect() protoreflect.Message
func (*SOMAnnotationEvent_Comment) Reset ¶
func (x *SOMAnnotationEvent_Comment) Reset()
func (*SOMAnnotationEvent_Comment) String ¶
func (x *SOMAnnotationEvent_Comment) String() string
type SOMAnnotationEvent_MonorailBug ¶
type SOMAnnotationEvent_MonorailBug struct {
BugId string `protobuf:"bytes,1,opt,name=bug_id,json=bugId,proto3" json:"bug_id,omitempty"`
ProjectId string `protobuf:"bytes,2,opt,name=project_id,json=projectId,proto3" json:"project_id,omitempty"`
// contains filtered or unexported fields
}
func (*SOMAnnotationEvent_MonorailBug) Descriptor
deprecated
func (*SOMAnnotationEvent_MonorailBug) Descriptor() ([]byte, []int)
Deprecated: Use SOMAnnotationEvent_MonorailBug.ProtoReflect.Descriptor instead.
func (*SOMAnnotationEvent_MonorailBug) GetBugId ¶
func (x *SOMAnnotationEvent_MonorailBug) GetBugId() string
func (*SOMAnnotationEvent_MonorailBug) GetProjectId ¶
func (x *SOMAnnotationEvent_MonorailBug) GetProjectId() string
func (*SOMAnnotationEvent_MonorailBug) ProtoMessage ¶
func (*SOMAnnotationEvent_MonorailBug) ProtoMessage()
func (*SOMAnnotationEvent_MonorailBug) ProtoReflect ¶
func (x *SOMAnnotationEvent_MonorailBug) ProtoReflect() protoreflect.Message
func (*SOMAnnotationEvent_MonorailBug) Reset ¶
func (x *SOMAnnotationEvent_MonorailBug) Reset()
func (*SOMAnnotationEvent_MonorailBug) String ¶
func (x *SOMAnnotationEvent_MonorailBug) String() string
type SOMAnnotationEvent_OperationType ¶
type SOMAnnotationEvent_OperationType int32
const ( SOMAnnotationEvent_ADD SOMAnnotationEvent_OperationType = 0 SOMAnnotationEvent_DELETE SOMAnnotationEvent_OperationType = 1 )
func (SOMAnnotationEvent_OperationType) Descriptor ¶
func (SOMAnnotationEvent_OperationType) Descriptor() protoreflect.EnumDescriptor
func (SOMAnnotationEvent_OperationType) Enum ¶
func (x SOMAnnotationEvent_OperationType) Enum() *SOMAnnotationEvent_OperationType
func (SOMAnnotationEvent_OperationType) EnumDescriptor
deprecated
func (SOMAnnotationEvent_OperationType) EnumDescriptor() ([]byte, []int)
Deprecated: Use SOMAnnotationEvent_OperationType.Descriptor instead.
func (SOMAnnotationEvent_OperationType) Number ¶
func (x SOMAnnotationEvent_OperationType) Number() protoreflect.EnumNumber
func (SOMAnnotationEvent_OperationType) String ¶
func (x SOMAnnotationEvent_OperationType) String() string
func (SOMAnnotationEvent_OperationType) Type ¶
func (SOMAnnotationEvent_OperationType) Type() protoreflect.EnumType