Documentation
¶
Overview ¶
Package access provides the Fleet Access API bindings.
Index ¶
- Variables
- func FileDescriptorSet() *descriptorpb.FileDescriptorSet
- func RegisterFleetServer(s prpc.Registrar, srv FleetServer)
- type CreateSessionRequest
- func (*CreateSessionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateSessionRequest) GetSession() *Session
- func (*CreateSessionRequest) ProtoMessage()
- func (x *CreateSessionRequest) ProtoReflect() protoreflect.Message
- func (x *CreateSessionRequest) Reset()
- func (x *CreateSessionRequest) String() string
- type DeleteSessionRequest
- func (*DeleteSessionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteSessionRequest) GetName() string
- func (*DeleteSessionRequest) ProtoMessage()
- func (x *DeleteSessionRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteSessionRequest) Reset()
- func (x *DeleteSessionRequest) String() string
- type FleetClient
- type FleetServer
- type GetSessionRequest
- type Session
- func (*Session) Descriptor() ([]byte, []int)deprecated
- func (x *Session) GetExpireTime() *timestamppb.Timestamp
- func (x *Session) GetName() string
- func (x *Session) GetTlwAddress() string
- func (*Session) ProtoMessage()
- func (x *Session) ProtoReflect() protoreflect.Message
- func (x *Session) Reset()
- func (x *Session) String() string
- type UnimplementedFleetServer
- func (*UnimplementedFleetServer) CreateSession(context.Context, *CreateSessionRequest) (*Session, error)
- func (*UnimplementedFleetServer) DeleteSession(context.Context, *DeleteSessionRequest) (*emptypb.Empty, error)
- func (*UnimplementedFleetServer) GetSession(context.Context, *GetSessionRequest) (*Session, error)
- func (*UnimplementedFleetServer) UpdateSession(context.Context, *UpdateSessionRequest) (*Session, error)
- type UpdateSessionRequest
- func (*UpdateSessionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateSessionRequest) GetSession() *Session
- func (x *UpdateSessionRequest) GetUpdateMask() *field_mask.FieldMask
- func (*UpdateSessionRequest) ProtoMessage()
- func (x *UpdateSessionRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateSessionRequest) Reset()
- func (x *UpdateSessionRequest) String() string
Constants ¶
This section is empty.
Variables ¶
var File_infra_cros_fleet_access_fleet_proto protoreflect.FileDescriptor
Functions ¶
func FileDescriptorSet ¶
func FileDescriptorSet() *descriptorpb.FileDescriptorSet
FileDescriptorSet returns a descriptor set for this proto package, which includes all defined services, and all transitive dependencies.
Will not return nil.
Do NOT modify the returned descriptor.
func RegisterFleetServer ¶
func RegisterFleetServer(s prpc.Registrar, srv FleetServer)
Types ¶
type CreateSessionRequest ¶
type CreateSessionRequest struct {
Session *Session `protobuf:"bytes,1,opt,name=session,proto3" json:"session,omitempty"`
// contains filtered or unexported fields
}
func (*CreateSessionRequest) Descriptor
deprecated
func (*CreateSessionRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateSessionRequest.ProtoReflect.Descriptor instead.
func (*CreateSessionRequest) GetSession ¶
func (x *CreateSessionRequest) GetSession() *Session
func (*CreateSessionRequest) ProtoMessage ¶
func (*CreateSessionRequest) ProtoMessage()
func (*CreateSessionRequest) ProtoReflect ¶
func (x *CreateSessionRequest) ProtoReflect() protoreflect.Message
func (*CreateSessionRequest) Reset ¶
func (x *CreateSessionRequest) Reset()
func (*CreateSessionRequest) String ¶
func (x *CreateSessionRequest) String() string
type DeleteSessionRequest ¶
type DeleteSessionRequest struct {
// The resource name of the session.
// Format: sessions/{session}
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteSessionRequest) Descriptor
deprecated
func (*DeleteSessionRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteSessionRequest.ProtoReflect.Descriptor instead.
func (*DeleteSessionRequest) GetName ¶
func (x *DeleteSessionRequest) GetName() string
func (*DeleteSessionRequest) ProtoMessage ¶
func (*DeleteSessionRequest) ProtoMessage()
func (*DeleteSessionRequest) ProtoReflect ¶
func (x *DeleteSessionRequest) ProtoReflect() protoreflect.Message
func (*DeleteSessionRequest) Reset ¶
func (x *DeleteSessionRequest) Reset()
func (*DeleteSessionRequest) String ¶
func (x *DeleteSessionRequest) String() string
type FleetClient ¶
type FleetClient interface {
// CreateSession creates a new session.
//
// This RPC follows https://google.aip.dev/133.
//
// Per AIP, the name of the Session in the request is ignored.
CreateSession(ctx context.Context, in *CreateSessionRequest, opts ...grpc.CallOption) (*Session, error)
// GetSession gets a session resource.
// This RPC follows https://google.aip.dev/131.
GetSession(ctx context.Context, in *GetSessionRequest, opts ...grpc.CallOption) (*Session, error)
// UpdateSession updates a session resource.
// This RPC follows https://google.aip.dev/134.
UpdateSession(ctx context.Context, in *UpdateSessionRequest, opts ...grpc.CallOption) (*Session, error)
// UpdateSession updates a session resource.
// This RPC follows https://google.aip.dev/135.
DeleteSession(ctx context.Context, in *DeleteSessionRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
}
FleetClient is the client API for Fleet service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewFleetClient ¶
func NewFleetClient(cc grpc.ClientConnInterface) FleetClient
func NewFleetPRPCClient ¶
func NewFleetPRPCClient(client *prpc.Client) FleetClient
type FleetServer ¶
type FleetServer interface {
// CreateSession creates a new session.
//
// This RPC follows https://google.aip.dev/133.
//
// Per AIP, the name of the Session in the request is ignored.
CreateSession(context.Context, *CreateSessionRequest) (*Session, error)
// GetSession gets a session resource.
// This RPC follows https://google.aip.dev/131.
GetSession(context.Context, *GetSessionRequest) (*Session, error)
// UpdateSession updates a session resource.
// This RPC follows https://google.aip.dev/134.
UpdateSession(context.Context, *UpdateSessionRequest) (*Session, error)
// UpdateSession updates a session resource.
// This RPC follows https://google.aip.dev/135.
DeleteSession(context.Context, *DeleteSessionRequest) (*emptypb.Empty, error)
}
FleetServer is the server API for Fleet service.
type GetSessionRequest ¶
type GetSessionRequest struct {
// The resource name of the session.
// Format: sessions/{session}
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*GetSessionRequest) Descriptor
deprecated
func (*GetSessionRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetSessionRequest.ProtoReflect.Descriptor instead.
func (*GetSessionRequest) GetName ¶
func (x *GetSessionRequest) GetName() string
func (*GetSessionRequest) ProtoMessage ¶
func (*GetSessionRequest) ProtoMessage()
func (*GetSessionRequest) ProtoReflect ¶
func (x *GetSessionRequest) ProtoReflect() protoreflect.Message
func (*GetSessionRequest) Reset ¶
func (x *GetSessionRequest) Reset()
func (*GetSessionRequest) String ¶
func (x *GetSessionRequest) String() string
type Session ¶
type Session struct {
// The resource name of the session.
// Format: sessions/{session}
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The network address of the TLW service for the session.
// This is in the standard IP address formats:
//
// 127.0.0.1:1234
// [::1]:1234
//
// This field is set automatically when a session is created.
// This field cannot be set or updated by clients and will be ignored.
TlwAddress string `protobuf:"bytes,2,opt,name=tlw_address,json=tlwAddress,proto3" json:"tlw_address,omitempty"`
// When the session will expire.
// Note that if this is not explicitly set during creation, it will
// default to the zero value and expire immediately.
ExpireTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=expire_time,json=expireTime,proto3" json:"expire_time,omitempty"`
// contains filtered or unexported fields
}
A Session tracks resources used by a Swarming task running on Fleet drones. Unless otherwise noted, fields default to the zero value.
func (*Session) Descriptor
deprecated
func (*Session) GetExpireTime ¶
func (x *Session) GetExpireTime() *timestamppb.Timestamp
func (*Session) GetTlwAddress ¶
func (*Session) ProtoMessage ¶
func (*Session) ProtoMessage()
func (*Session) ProtoReflect ¶
func (x *Session) ProtoReflect() protoreflect.Message
type UnimplementedFleetServer ¶
type UnimplementedFleetServer struct {
}
UnimplementedFleetServer can be embedded to have forward compatible implementations.
func (*UnimplementedFleetServer) CreateSession ¶
func (*UnimplementedFleetServer) CreateSession(context.Context, *CreateSessionRequest) (*Session, error)
func (*UnimplementedFleetServer) DeleteSession ¶
func (*UnimplementedFleetServer) DeleteSession(context.Context, *DeleteSessionRequest) (*emptypb.Empty, error)
func (*UnimplementedFleetServer) GetSession ¶
func (*UnimplementedFleetServer) GetSession(context.Context, *GetSessionRequest) (*Session, error)
func (*UnimplementedFleetServer) UpdateSession ¶
func (*UnimplementedFleetServer) UpdateSession(context.Context, *UpdateSessionRequest) (*Session, error)
type UpdateSessionRequest ¶
type UpdateSessionRequest struct {
// The session to update.
//
// The session's `name` field is used to identify the session to be updated.
Session *Session `protobuf:"bytes,1,opt,name=session,proto3" json:"session,omitempty"`
// The list of fields to be updated.
UpdateMask *field_mask.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateSessionRequest) Descriptor
deprecated
func (*UpdateSessionRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateSessionRequest.ProtoReflect.Descriptor instead.
func (*UpdateSessionRequest) GetSession ¶
func (x *UpdateSessionRequest) GetSession() *Session
func (*UpdateSessionRequest) GetUpdateMask ¶
func (x *UpdateSessionRequest) GetUpdateMask() *field_mask.FieldMask
func (*UpdateSessionRequest) ProtoMessage ¶
func (*UpdateSessionRequest) ProtoMessage()
func (*UpdateSessionRequest) ProtoReflect ¶
func (x *UpdateSessionRequest) ProtoReflect() protoreflect.Message
func (*UpdateSessionRequest) Reset ¶
func (x *UpdateSessionRequest) Reset()
func (*UpdateSessionRequest) String ¶
func (x *UpdateSessionRequest) String() string