Documentation
¶
Overview ¶
Package dynamicsuite provides a library to create control.cros_test_platform suite requests that inject arbitrary arguments into autotest.dynamic_suite.reimage_and_run(...). This is used as an entry point for cros_test_platform when launching legacy autotest suites.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRequest ¶
func NewRequest(args Args) (*swarming.SwarmingRpcsNewTaskRequest, error)
NewRequest creates a new swarming request for the given entry point arguments.
Types ¶
type Args ¶
type Args struct {
Board string
Build string
FirmwareROBuild string
FirmwareRWBuild string
Model string
Pool string
Priority int
AfeHost string
Timeout time.Duration
// ReimageAndRunArgs specifies arguments to be passed into
// autotest.dynamic_suite.reimage_and_run. This object must be
// json-encodable.
ReimageAndRunArgs interface{}
// If specified, ignore ReimageAndRunArgs and just run this named
// autotest suite.
LegacySuite string
}
Args encapsulates arguments for forming a request.
Click to show internal directories.
Click to hide internal directories.