Documentation
¶
Overview ¶
Package proxy provides a library to create swarming requests for an autotest-swarming-proxy task.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRunSuite ¶
func NewRunSuite(args RunSuiteArgs) (*swarming.SwarmingRpcsNewTaskRequest, error)
NewRunSuite creates a new swarming request for the given run suite args.
Types ¶
type RunSuiteArgs ¶
type RunSuiteArgs struct {
Build string
FirmwareRWBuild string
FirmwareROBuild string
Board string
Model string
SuiteName string
Pool string
Priority int
AfeHost string
Timeout time.Duration
// SuiteArgs are the arguments to be passed into the suite. This object
// must be json-encodable, or an error will be returned.
SuiteArgs interface{}
}
RunSuiteArgs defines the set of arguments for creating a run_suite request.
Click to show internal directories.
Click to hide internal directories.