Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Affectedness ¶
type Affectedness struct {
// Distance is a non-negative number, where 0.0 means the code change is
// extremely likely to affect the test, and +inf means extremely unlikely.
// If a test's distance is less or equal than a given threshold, then the test
// is selected.
//
// A selection strategy doesn't have to use +inf as the upper boundary.
// It may use the range [0.0, 1.0] as well, as long as the threshold uses
// the same scale.
Distance float64
}
Affectedness is how much a test is affected by the code change. The zero value means a test is very affected.
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
filegraph
command
|
|
|
rts-chromium
command
Command rts-chromium is Chromium-specific part of the generic RTS framework.
|
Command rts-chromium is Chromium-specific part of the generic RTS framework. |
|
rts-random
command
|
|
|
Package filegraph implements a directed weighted graph of files, where the weight of edge (x, y), called distance, represents how much y is affected by changes in x.
|
Package filegraph implements a directed weighted graph of files, where the weight of edge (x, y), called distance, represents how much y is affected by changes in x. |
|
cli
Package cli implements filegraph command.
|
Package cli implements filegraph command. |
|
git
Package git implements derivation of a file graph from git log and optionally from the file structure.
|
Package git implements derivation of a file graph from git log and optionally from the file structure. |
|
internal
|
|
|
presubmit
|
|
|
eval
Package eval implements a framework for selection strategy evaluation.
|
Package eval implements a framework for selection strategy evaluation. |
Click to show internal directories.
Click to hide internal directories.