Documentation
¶
Index ¶
- Variables
- type DistanceStats
- func (*DistanceStats) Descriptor() ([]byte, []int)deprecated
- func (x *DistanceStats) GetMaxNonInf() float32
- func (x *DistanceStats) GetPercentiles() []float32
- func (*DistanceStats) ProtoMessage()
- func (x *DistanceStats) ProtoReflect() protoreflect.Message
- func (x *DistanceStats) Reset()
- func (x *DistanceStats) String() string
- type GerritChange
- func (*GerritChange) Descriptor() ([]byte, []int)deprecated
- func (x *GerritChange) GetHost() string
- func (x *GerritChange) GetNumber() int64
- func (x *GerritChange) GetProject() string
- func (*GerritChange) ProtoMessage()
- func (x *GerritChange) ProtoReflect() protoreflect.Message
- func (x *GerritChange) Reset()
- func (x *GerritChange) String() string
- type GerritPatchset
- func (*GerritPatchset) Descriptor() ([]byte, []int)deprecated
- func (x *GerritPatchset) GetChange() *GerritChange
- func (x *GerritPatchset) GetChangedFiles() []*SourceFile
- func (x *GerritPatchset) GetPatchset() int64
- func (*GerritPatchset) ProtoMessage()
- func (x *GerritPatchset) ProtoReflect() protoreflect.Message
- func (x *GerritPatchset) Reset()
- func (x *GerritPatchset) String() string
- type Rejection
- func (*Rejection) Descriptor() ([]byte, []int)deprecated
- func (x *Rejection) GetFailedTestVariants() []*TestVariant
- func (x *Rejection) GetPatchsets() []*GerritPatchset
- func (x *Rejection) GetTimestamp() *timestamppb.Timestamp
- func (*Rejection) ProtoMessage()
- func (x *Rejection) ProtoReflect() protoreflect.Message
- func (x *Rejection) Reset()
- func (x *Rejection) String() string
- type Results
- func (*Results) Descriptor() ([]byte, []int)deprecated
- func (x *Results) GetRejectionClosestDistanceStats() *DistanceStats
- func (x *Results) GetThresholds() []*Threshold
- func (x *Results) GetTotalDuration() *durationpb.Duration
- func (x *Results) GetTotalRejections() int64
- func (x *Results) GetTotalTestFailures() int64
- func (*Results) ProtoMessage()
- func (x *Results) ProtoReflect() protoreflect.Message
- func (x *Results) Reset()
- func (x *Results) String() string
- type SourceFile
- type TestDuration
- func (*TestDuration) Descriptor() ([]byte, []int)deprecated
- func (x *TestDuration) GetDuration() *durationpb.Duration
- func (x *TestDuration) GetTestVariant() *TestVariant
- func (*TestDuration) ProtoMessage()
- func (x *TestDuration) ProtoReflect() protoreflect.Message
- func (x *TestDuration) Reset()
- func (x *TestDuration) String() string
- type TestDurationRecord
- func (*TestDurationRecord) Descriptor() ([]byte, []int)deprecated
- func (x *TestDurationRecord) GetPatchsets() []*GerritPatchset
- func (x *TestDurationRecord) GetTestDurations() []*TestDuration
- func (*TestDurationRecord) ProtoMessage()
- func (x *TestDurationRecord) ProtoReflect() protoreflect.Message
- func (x *TestDurationRecord) Reset()
- func (x *TestDurationRecord) String() string
- type TestVariant
- func (*TestVariant) Descriptor() ([]byte, []int)deprecated
- func (x *TestVariant) GetFileName() string
- func (x *TestVariant) GetId() string
- func (x *TestVariant) GetVariant() []string
- func (*TestVariant) ProtoMessage()
- func (x *TestVariant) ProtoReflect() protoreflect.Message
- func (x *TestVariant) Reset()
- func (x *TestVariant) String() string
- type Threshold
- func (*Threshold) Descriptor() ([]byte, []int)deprecated
- func (x *Threshold) GetChangeRecall() float32
- func (x *Threshold) GetMaxDistance() float32
- func (x *Threshold) GetPreservedRejections() int64
- func (x *Threshold) GetPreservedTestFailures() int64
- func (x *Threshold) GetSavedDuration() *durationpb.Duration
- func (x *Threshold) GetSavings() float32
- func (x *Threshold) GetTestRecall() float32
- func (*Threshold) ProtoMessage()
- func (x *Threshold) ProtoReflect() protoreflect.Message
- func (x *Threshold) Reset()
- func (x *Threshold) String() string
Constants ¶
This section is empty.
Variables ¶
var File_infra_rts_presubmit_eval_proto_dataset_proto protoreflect.FileDescriptor
var File_infra_rts_presubmit_eval_proto_results_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type DistanceStats ¶
type DistanceStats struct {
Percentiles []float32 `protobuf:"fixed32,1,rep,packed,name=percentiles,proto3" json:"percentiles,omitempty"`
// Maximum non-infinity distance.
MaxNonInf float32 `protobuf:"fixed32,2,opt,name=max_non_inf,json=maxNonInf,proto3" json:"max_non_inf,omitempty"`
// contains filtered or unexported fields
}
Collected statistics of distances.
func (*DistanceStats) Descriptor
deprecated
func (*DistanceStats) Descriptor() ([]byte, []int)
Deprecated: Use DistanceStats.ProtoReflect.Descriptor instead.
func (*DistanceStats) GetMaxNonInf ¶
func (x *DistanceStats) GetMaxNonInf() float32
func (*DistanceStats) GetPercentiles ¶
func (x *DistanceStats) GetPercentiles() []float32
func (*DistanceStats) ProtoMessage ¶
func (*DistanceStats) ProtoMessage()
func (*DistanceStats) ProtoReflect ¶
func (x *DistanceStats) ProtoReflect() protoreflect.Message
func (*DistanceStats) Reset ¶
func (x *DistanceStats) Reset()
func (*DistanceStats) String ¶
func (x *DistanceStats) String() string
type GerritChange ¶
type GerritChange struct {
// Gerrit host, e.g. "chromium-review.googlesource.com".
Host string `protobuf:"bytes,1,opt,name=host,proto3" json:"host,omitempty"`
// Gerrit project, e.g. "chromium/src".
// It is required.
Project string `protobuf:"bytes,2,opt,name=project,proto3" json:"project,omitempty"`
// Change number,
// e.g. 123 for https://chromium.googlesource.com/c/123
Number int64 `protobuf:"varint,3,opt,name=number,proto3" json:"number,omitempty"`
// contains filtered or unexported fields
}
A Gerrit CL.
func (*GerritChange) Descriptor
deprecated
func (*GerritChange) Descriptor() ([]byte, []int)
Deprecated: Use GerritChange.ProtoReflect.Descriptor instead.
func (*GerritChange) GetHost ¶
func (x *GerritChange) GetHost() string
func (*GerritChange) GetNumber ¶
func (x *GerritChange) GetNumber() int64
func (*GerritChange) GetProject ¶
func (x *GerritChange) GetProject() string
func (*GerritChange) ProtoMessage ¶
func (*GerritChange) ProtoMessage()
func (*GerritChange) ProtoReflect ¶
func (x *GerritChange) ProtoReflect() protoreflect.Message
func (*GerritChange) Reset ¶
func (x *GerritChange) Reset()
func (*GerritChange) String ¶
func (x *GerritChange) String() string
type GerritPatchset ¶
type GerritPatchset struct {
// The CL.
Change *GerritChange `protobuf:"bytes,1,opt,name=change,proto3" json:"change,omitempty"`
// The patchset number.
Patchset int64 `protobuf:"varint,2,opt,name=patchset,proto3" json:"patchset,omitempty"`
// The files changed in the patchset.
ChangedFiles []*SourceFile `protobuf:"bytes,3,rep,name=changed_files,json=changedFiles,proto3" json:"changed_files,omitempty"`
// contains filtered or unexported fields
}
A Gerrit patchset.
func (*GerritPatchset) Descriptor
deprecated
func (*GerritPatchset) Descriptor() ([]byte, []int)
Deprecated: Use GerritPatchset.ProtoReflect.Descriptor instead.
func (*GerritPatchset) GetChange ¶
func (x *GerritPatchset) GetChange() *GerritChange
func (*GerritPatchset) GetChangedFiles ¶
func (x *GerritPatchset) GetChangedFiles() []*SourceFile
func (*GerritPatchset) GetPatchset ¶
func (x *GerritPatchset) GetPatchset() int64
func (*GerritPatchset) ProtoMessage ¶
func (*GerritPatchset) ProtoMessage()
func (*GerritPatchset) ProtoReflect ¶
func (x *GerritPatchset) ProtoReflect() protoreflect.Message
func (*GerritPatchset) Reset ¶
func (x *GerritPatchset) Reset()
func (*GerritPatchset) String ¶
func (x *GerritPatchset) String() string
type Rejection ¶
type Rejection struct {
// The rejected patchsets.
Patchsets []*GerritPatchset `protobuf:"bytes,1,rep,name=patchsets,proto3" json:"patchsets,omitempty"`
// When the code change was rejected.
Timestamp *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
// List of test variants that caused the rejection.
FailedTestVariants []*TestVariant `protobuf:"bytes,3,rep,name=failed_test_variants,json=failedTestVariants,proto3" json:"failed_test_variants,omitempty"`
// contains filtered or unexported fields
}
A rejection of a code change due to test failures.
Normally these messages are in a directory where .jsonl.gz files are GZIP-compressed JSON Lines files, where each entry is a protojson-encoded Rejection message.
func (*Rejection) Descriptor
deprecated
func (*Rejection) GetFailedTestVariants ¶
func (x *Rejection) GetFailedTestVariants() []*TestVariant
func (*Rejection) GetPatchsets ¶
func (x *Rejection) GetPatchsets() []*GerritPatchset
func (*Rejection) GetTimestamp ¶
func (x *Rejection) GetTimestamp() *timestamppb.Timestamp
func (*Rejection) ProtoMessage ¶
func (*Rejection) ProtoMessage()
func (*Rejection) ProtoReflect ¶
func (x *Rejection) ProtoReflect() protoreflect.Message
type Results ¶
type Results struct {
// Considered thresholds and their results.
// Sorted by ascending ChangeRecall.
Thresholds []*Threshold `protobuf:"bytes,1,rep,name=thresholds,proto3" json:"thresholds,omitempty"`
// The number of analyzed rejections.
TotalRejections int64 `protobuf:"varint,2,opt,name=total_rejections,json=totalRejections,proto3" json:"total_rejections,omitempty"`
// The number of analyzed test failures.
TotalTestFailures int64 `protobuf:"varint,3,opt,name=total_test_failures,json=totalTestFailures,proto3" json:"total_test_failures,omitempty"`
// The sum of analyzed test durations.
TotalDuration *durationpb.Duration `protobuf:"bytes,4,opt,name=total_duration,json=totalDuration,proto3" json:"total_duration,omitempty"`
// Statistics of the distance to the closest failed test, for each rejection.
RejectionClosestDistanceStats *DistanceStats `` /* 152-byte string literal not displayed */
// contains filtered or unexported fields
}
Results of evaluation.
func (*Results) Descriptor
deprecated
func (*Results) GetRejectionClosestDistanceStats ¶
func (x *Results) GetRejectionClosestDistanceStats() *DistanceStats
func (*Results) GetThresholds ¶
func (*Results) GetTotalDuration ¶
func (x *Results) GetTotalDuration() *durationpb.Duration
func (*Results) GetTotalRejections ¶
func (*Results) GetTotalTestFailures ¶
func (*Results) ProtoMessage ¶
func (*Results) ProtoMessage()
func (*Results) ProtoReflect ¶
func (x *Results) ProtoReflect() protoreflect.Message
type SourceFile ¶
type SourceFile struct {
// The repository identifier.
// For googlesource.com repositories, it is a canonical URL, e.g.
// https://chromium.googlesource.com/chromium/src
Repo string `protobuf:"bytes,1,opt,name=repo,proto3" json:"repo,omitempty"`
// The file relative to the repo root. Starts with "//".
Path string `protobuf:"bytes,2,opt,name=path,proto3" json:"path,omitempty"`
// contains filtered or unexported fields
}
Identifies a source file.
func (*SourceFile) Descriptor
deprecated
func (*SourceFile) Descriptor() ([]byte, []int)
Deprecated: Use SourceFile.ProtoReflect.Descriptor instead.
func (*SourceFile) GetPath ¶
func (x *SourceFile) GetPath() string
func (*SourceFile) GetRepo ¶
func (x *SourceFile) GetRepo() string
func (*SourceFile) ProtoMessage ¶
func (*SourceFile) ProtoMessage()
func (*SourceFile) ProtoReflect ¶
func (x *SourceFile) ProtoReflect() protoreflect.Message
func (*SourceFile) Reset ¶
func (x *SourceFile) Reset()
func (*SourceFile) String ¶
func (x *SourceFile) String() string
type TestDuration ¶
type TestDuration struct {
// The test variant that was measured.
TestVariant *TestVariant `protobuf:"bytes,1,opt,name=test_variant,json=testVariant,proto3" json:"test_variant,omitempty"`
// How long test execution took.
Duration *durationpb.Duration `protobuf:"bytes,2,opt,name=duration,proto3" json:"duration,omitempty"`
// contains filtered or unexported fields
}
How long a test took.
func (*TestDuration) Descriptor
deprecated
func (*TestDuration) Descriptor() ([]byte, []int)
Deprecated: Use TestDuration.ProtoReflect.Descriptor instead.
func (*TestDuration) GetDuration ¶
func (x *TestDuration) GetDuration() *durationpb.Duration
func (*TestDuration) GetTestVariant ¶
func (x *TestDuration) GetTestVariant() *TestVariant
func (*TestDuration) ProtoMessage ¶
func (*TestDuration) ProtoMessage()
func (*TestDuration) ProtoReflect ¶
func (x *TestDuration) ProtoReflect() protoreflect.Message
func (*TestDuration) Reset ¶
func (x *TestDuration) Reset()
func (*TestDuration) String ¶
func (x *TestDuration) String() string
type TestDurationRecord ¶
type TestDurationRecord struct {
// The patchset set that observed the test durations.
Patchsets []*GerritPatchset `protobuf:"bytes,1,rep,name=patchsets,proto3" json:"patchsets,omitempty"`
// A sample of test durations from results of the patchsets.
TestDurations []*TestDuration `protobuf:"bytes,2,rep,name=test_durations,json=testDurations,proto3" json:"test_durations,omitempty"`
// contains filtered or unexported fields
}
Code changes and a sample of test runs with their durations.
Normally these records are in a directory where .jsonl.gz files are GZIP-compressed JSON Lines files, where each entry is a protojson-encoded TestDurationRecord message.
func (*TestDurationRecord) Descriptor
deprecated
func (*TestDurationRecord) Descriptor() ([]byte, []int)
Deprecated: Use TestDurationRecord.ProtoReflect.Descriptor instead.
func (*TestDurationRecord) GetPatchsets ¶
func (x *TestDurationRecord) GetPatchsets() []*GerritPatchset
func (*TestDurationRecord) GetTestDurations ¶
func (x *TestDurationRecord) GetTestDurations() []*TestDuration
func (*TestDurationRecord) ProtoMessage ¶
func (*TestDurationRecord) ProtoMessage()
func (*TestDurationRecord) ProtoReflect ¶
func (x *TestDurationRecord) ProtoReflect() protoreflect.Message
func (*TestDurationRecord) Reset ¶
func (x *TestDurationRecord) Reset()
func (*TestDurationRecord) String ¶
func (x *TestDurationRecord) String() string
type TestVariant ¶
type TestVariant struct {
// Test identifier.
// For Chromium, a ResultDB TestID.
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// One particular way to run this test, expressed as domain-specific key-value
// pairs. Each element has format "<key>:<value>".
// For Chromium, this is a ResultDB test variant.
//
// The keys must be unique. This is not a map for conveniency of extracting
// from BigQuery which cannot convert tabular data to JSON objects with
// dynamic keys.
Variant []string `protobuf:"bytes,2,rep,name=variant,proto3" json:"variant,omitempty"`
// Path of the file where the test is defined.
FileName string `protobuf:"bytes,3,opt,name=file_name,json=fileName,proto3" json:"file_name,omitempty"`
// contains filtered or unexported fields
}
A single way to run a single test. For example, a particular test case on Windows 10.
func (*TestVariant) Descriptor
deprecated
func (*TestVariant) Descriptor() ([]byte, []int)
Deprecated: Use TestVariant.ProtoReflect.Descriptor instead.
func (*TestVariant) GetFileName ¶
func (x *TestVariant) GetFileName() string
func (*TestVariant) GetId ¶
func (x *TestVariant) GetId() string
func (*TestVariant) GetVariant ¶
func (x *TestVariant) GetVariant() []string
func (*TestVariant) ProtoMessage ¶
func (*TestVariant) ProtoMessage()
func (*TestVariant) ProtoReflect ¶
func (x *TestVariant) ProtoReflect() protoreflect.Message
func (*TestVariant) Reset ¶
func (x *TestVariant) Reset()
func (*TestVariant) String ¶
func (x *TestVariant) String() string
type Threshold ¶
type Threshold struct {
// The maximum distance to select a test.
// Tests further than this are skipped.
MaxDistance float32 `protobuf:"fixed32,1,opt,name=max_distance,json=maxDistance,proto3" json:"max_distance,omitempty"`
// The number of rejections where at least one failed test was selected.
PreservedRejections int64 `protobuf:"varint,2,opt,name=preserved_rejections,json=preservedRejections,proto3" json:"preserved_rejections,omitempty"`
// The number of selected failed tests.
PreservedTestFailures int64 `` /* 127-byte string literal not displayed */
// The sum of test durations for skipped tests.
SavedDuration *durationpb.Duration `protobuf:"bytes,4,opt,name=saved_duration,json=savedDuration,proto3" json:"saved_duration,omitempty"`
// The fraction of rejections that were preserved. May be NaN.
ChangeRecall float32 `protobuf:"fixed32,5,opt,name=change_recall,json=changeRecall,proto3" json:"change_recall,omitempty"`
// The fraction of test failures that were preserved.
TestRecall float32 `protobuf:"fixed32,6,opt,name=test_recall,json=testRecall,proto3" json:"test_recall,omitempty"`
// The fraction of test duration that was cut.
Savings float32 `protobuf:"fixed32,7,opt,name=savings,proto3" json:"savings,omitempty"`
// contains filtered or unexported fields
}
Distance threshold and its scores.
func (*Threshold) Descriptor
deprecated
func (*Threshold) GetChangeRecall ¶
func (*Threshold) GetMaxDistance ¶
func (*Threshold) GetPreservedRejections ¶
func (*Threshold) GetPreservedTestFailures ¶
func (*Threshold) GetSavedDuration ¶
func (x *Threshold) GetSavedDuration() *durationpb.Duration
func (*Threshold) GetSavings ¶
func (*Threshold) GetTestRecall ¶
func (*Threshold) ProtoMessage ¶
func (*Threshold) ProtoMessage()
func (*Threshold) ProtoReflect ¶
func (x *Threshold) ProtoReflect() protoreflect.Message