Documentation
¶
Overview ¶
Package updater computes inherited metadata and uploads it to GCS. It is is very specific to Chromium and is full of assumptions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Updater ¶
type Updater struct {
// ChromiumCheckout is a path to chromium/src.git checkout.
ChromiumCheckout string
// GCSBucket is the destination bucket for metadata.
GCSBucket *storage.BucketHandle
// LegacyGSBucket is the destination bucket for metadata in legacy format.
GCSBucketLegacy *storage.BucketHandle
// OutDir is a path to the directory where to write output files.
OutDir string
}
Updater computed metadata from a Chromium checkout and uploads it to GCS.
Click to show internal directories.
Click to hide internal directories.