Documentation
¶
Index ¶
- Variables
- type BuildRunResult
- func (*BuildRunResult) Descriptor() ([]byte, []int)deprecated
- func (x *BuildRunResult) GetAnnotationUrl() string
- func (x *BuildRunResult) GetAnnotations() *proto1.Step
- func (x *BuildRunResult) GetInfraFailure() *InfraFailure
- func (x *BuildRunResult) GetRecipe() *BuildRunResult_Recipe
- func (x *BuildRunResult) GetRecipeExitCode() *OptionalInt32
- func (x *BuildRunResult) GetRecipeResult() *recipe_engine.Result
- func (*BuildRunResult) ProtoMessage()
- func (x *BuildRunResult) ProtoReflect() protoreflect.Message
- func (x *BuildRunResult) Reset()
- func (x *BuildRunResult) String() string
- type BuildRunResult_Recipe
- func (*BuildRunResult_Recipe) Descriptor() ([]byte, []int)deprecated
- func (x *BuildRunResult_Recipe) GetName() string
- func (x *BuildRunResult_Recipe) GetRepository() string
- func (x *BuildRunResult_Recipe) GetRevision() string
- func (*BuildRunResult_Recipe) ProtoMessage()
- func (x *BuildRunResult_Recipe) ProtoReflect() protoreflect.Message
- func (x *BuildRunResult_Recipe) Reset()
- func (x *BuildRunResult_Recipe) String() string
- type InfraFailure
- func (*InfraFailure) Descriptor() ([]byte, []int)deprecated
- func (x *InfraFailure) GetBootstrapperCallStack() []string
- func (x *InfraFailure) GetText() string
- func (x *InfraFailure) GetType() InfraFailure_Type
- func (*InfraFailure) ProtoMessage()
- func (x *InfraFailure) ProtoReflect() protoreflect.Message
- func (x *InfraFailure) Reset()
- func (x *InfraFailure) String() string
- type InfraFailure_Type
- func (InfraFailure_Type) Descriptor() protoreflect.EnumDescriptor
- func (x InfraFailure_Type) Enum() *InfraFailure_Type
- func (InfraFailure_Type) EnumDescriptor() ([]byte, []int)deprecated
- func (x InfraFailure_Type) Number() protoreflect.EnumNumber
- func (x InfraFailure_Type) String() string
- func (InfraFailure_Type) Type() protoreflect.EnumType
- type OptionalInt32
Constants ¶
This section is empty.
Variables ¶
var ( InfraFailure_Type_name = map[int32]string{ 0: "BOOTSTRAPPER_ERROR", 1: "INVALID_INPUT", 2: "CANCELED", 3: "RECIPE_INFRA_FAILURE", } InfraFailure_Type_value = map[string]int32{ "BOOTSTRAPPER_ERROR": 0, "INVALID_INPUT": 1, "CANCELED": 2, "RECIPE_INFRA_FAILURE": 3, } )
Enum value maps for InfraFailure_Type.
var File_infra_tools_kitchen_build_result_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type BuildRunResult ¶
type BuildRunResult struct {
// A failure of the build infrastructure.
// A build with an infra failure cannot be used to judge the build input
// (e.g. a CL).
InfraFailure *InfraFailure `protobuf:"bytes,1,opt,name=infra_failure,json=infraFailure,proto3" json:"infra_failure,omitempty"`
// recipes.py's exit code.
RecipeExitCode *OptionalInt32 `protobuf:"bytes,2,opt,name=recipe_exit_code,json=recipeExitCode,proto3" json:"recipe_exit_code,omitempty"`
// Results returned by recipe engine.
RecipeResult *recipe_engine.Result `protobuf:"bytes,3,opt,name=recipe_result,json=recipeResult,proto3" json:"recipe_result,omitempty"`
// Final state of the annotation proto.
Annotations *proto1.Step `protobuf:"bytes,4,opt,name=annotations,proto3" json:"annotations,omitempty"`
// URL where the annotations (above) can be fetched from.
// In practice, a LogDog URL.
AnnotationUrl string `protobuf:"bytes,5,opt,name=annotation_url,json=annotationUrl,proto3" json:"annotation_url,omitempty"`
Recipe *BuildRunResult_Recipe `protobuf:"bytes,6,opt,name=recipe,proto3" json:"recipe,omitempty"`
// contains filtered or unexported fields
}
Result of a build run from the perspective of a build bootstrapper.
func (*BuildRunResult) Descriptor
deprecated
func (*BuildRunResult) Descriptor() ([]byte, []int)
Deprecated: Use BuildRunResult.ProtoReflect.Descriptor instead.
func (*BuildRunResult) GetAnnotationUrl ¶
func (x *BuildRunResult) GetAnnotationUrl() string
func (*BuildRunResult) GetAnnotations ¶
func (x *BuildRunResult) GetAnnotations() *proto1.Step
func (*BuildRunResult) GetInfraFailure ¶
func (x *BuildRunResult) GetInfraFailure() *InfraFailure
func (*BuildRunResult) GetRecipe ¶
func (x *BuildRunResult) GetRecipe() *BuildRunResult_Recipe
func (*BuildRunResult) GetRecipeExitCode ¶
func (x *BuildRunResult) GetRecipeExitCode() *OptionalInt32
func (*BuildRunResult) GetRecipeResult ¶
func (x *BuildRunResult) GetRecipeResult() *recipe_engine.Result
func (*BuildRunResult) ProtoMessage ¶
func (*BuildRunResult) ProtoMessage()
func (*BuildRunResult) ProtoReflect ¶
func (x *BuildRunResult) ProtoReflect() protoreflect.Message
func (*BuildRunResult) Reset ¶
func (x *BuildRunResult) Reset()
func (*BuildRunResult) String ¶
func (x *BuildRunResult) String() string
type BuildRunResult_Recipe ¶
type BuildRunResult_Recipe struct {
// The name of the recipe that was executed.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Repository is the recipe repository that was checked out.
// will not have a revision field.
Repository string `protobuf:"bytes,2,opt,name=repository,proto3" json:"repository,omitempty"`
// The revision of the recipe repository.
Revision string `protobuf:"bytes,3,opt,name=revision,proto3" json:"revision,omitempty"`
// contains filtered or unexported fields
}
Information about the recipe checkout that was used. If the recipes weren't checked out (e.g., isolated bundle, local), this will be empty.
func (*BuildRunResult_Recipe) Descriptor
deprecated
func (*BuildRunResult_Recipe) Descriptor() ([]byte, []int)
Deprecated: Use BuildRunResult_Recipe.ProtoReflect.Descriptor instead.
func (*BuildRunResult_Recipe) GetName ¶
func (x *BuildRunResult_Recipe) GetName() string
func (*BuildRunResult_Recipe) GetRepository ¶
func (x *BuildRunResult_Recipe) GetRepository() string
func (*BuildRunResult_Recipe) GetRevision ¶
func (x *BuildRunResult_Recipe) GetRevision() string
func (*BuildRunResult_Recipe) ProtoMessage ¶
func (*BuildRunResult_Recipe) ProtoMessage()
func (*BuildRunResult_Recipe) ProtoReflect ¶
func (x *BuildRunResult_Recipe) ProtoReflect() protoreflect.Message
func (*BuildRunResult_Recipe) Reset ¶
func (x *BuildRunResult_Recipe) Reset()
func (*BuildRunResult_Recipe) String ¶
func (x *BuildRunResult_Recipe) String() string
type InfraFailure ¶
type InfraFailure struct {
Type InfraFailure_Type `protobuf:"varint,1,opt,name=type,proto3,enum=luci.build.InfraFailure_Type" json:"type,omitempty"`
Text string `protobuf:"bytes,2,opt,name=text,proto3" json:"text,omitempty"`
// Build bootstrapper call stack is populated on bootstrapper errors.
BootstrapperCallStack []string `` /* 126-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*InfraFailure) Descriptor
deprecated
func (*InfraFailure) Descriptor() ([]byte, []int)
Deprecated: Use InfraFailure.ProtoReflect.Descriptor instead.
func (*InfraFailure) GetBootstrapperCallStack ¶
func (x *InfraFailure) GetBootstrapperCallStack() []string
func (*InfraFailure) GetText ¶
func (x *InfraFailure) GetText() string
func (*InfraFailure) GetType ¶
func (x *InfraFailure) GetType() InfraFailure_Type
func (*InfraFailure) ProtoMessage ¶
func (*InfraFailure) ProtoMessage()
func (*InfraFailure) ProtoReflect ¶
func (x *InfraFailure) ProtoReflect() protoreflect.Message
func (*InfraFailure) Reset ¶
func (x *InfraFailure) Reset()
func (*InfraFailure) String ¶
func (x *InfraFailure) String() string
type InfraFailure_Type ¶
type InfraFailure_Type int32
const ( // An unexpected internal error happened inside build bootstrapper. InfraFailure_BOOTSTRAPPER_ERROR InfraFailure_Type = 0 // Build bootstrapper input was invalid, for example flags. InfraFailure_INVALID_INPUT InfraFailure_Type = 1 // Build run was cancelled. InfraFailure_CANCELED InfraFailure_Type = 2 // Recipe has infra-failed. InfraFailure_RECIPE_INFRA_FAILURE InfraFailure_Type = 3 )
func (InfraFailure_Type) Descriptor ¶
func (InfraFailure_Type) Descriptor() protoreflect.EnumDescriptor
func (InfraFailure_Type) Enum ¶
func (x InfraFailure_Type) Enum() *InfraFailure_Type
func (InfraFailure_Type) EnumDescriptor
deprecated
func (InfraFailure_Type) EnumDescriptor() ([]byte, []int)
Deprecated: Use InfraFailure_Type.Descriptor instead.
func (InfraFailure_Type) Number ¶
func (x InfraFailure_Type) Number() protoreflect.EnumNumber
func (InfraFailure_Type) String ¶
func (x InfraFailure_Type) String() string
func (InfraFailure_Type) Type ¶
func (InfraFailure_Type) Type() protoreflect.EnumType
type OptionalInt32 ¶
type OptionalInt32 struct {
Value int32 `protobuf:"varint,1,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
An int32 that can be distinguished from absence of the value.
func (*OptionalInt32) Descriptor
deprecated
func (*OptionalInt32) Descriptor() ([]byte, []int)
Deprecated: Use OptionalInt32.ProtoReflect.Descriptor instead.
func (*OptionalInt32) GetValue ¶
func (x *OptionalInt32) GetValue() int32
func (*OptionalInt32) ProtoMessage ¶
func (*OptionalInt32) ProtoMessage()
func (*OptionalInt32) ProtoReflect ¶
func (x *OptionalInt32) ProtoReflect() protoreflect.Message
func (*OptionalInt32) Reset ¶
func (x *OptionalInt32) Reset()
func (*OptionalInt32) String ¶
func (x *OptionalInt32) String() string
Click to show internal directories.
Click to hide internal directories.